% Auto-generated chapter 31 for ibnmajah
% Hadiths in this chapter: 114

\hadithdefcmd{ibnmajah}{3436}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ أُسَامَةَ بْنِ شَرِيكٍ، قَالَ شَهِدْتُ الأَعْرَابَ يَسْأَلُونَ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَعَلَيْنَا حَرَجٌ فِي كَذَا أَعَلَيْنَا حَرَجٌ فِي كَذَا فَقَالَ لَهُمْ ‏"‏ عِبَادَ اللَّهِ وَضَعَ اللَّهُ الْحَرَجَ إِلاَّ مَنِ اقْتَرَضَ مِنْ عِرْضِ أَخِيهِ شَيْئًا فَذَاكَ الَّذِي حَرَجٌ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ هَلْ عَلَيْنَا جُنَاحٌ أَنْ نَتَدَاوَى قَالَ ‏"‏ تَدَاوَوْا عِبَادَ اللَّهِ فَإِنَّ اللَّهَ سُبْحَانَهُ لَمْ يَضَعْ دَاءً إِلاَّ وَضَعَ مَعَهُ شِفَاءً إِلاَّ الْهَرَمَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا خَيْرُ مَا أُعْطِيَ الْعَبْدُ قَالَ ‏"‏ خُلُقٌ حَسَنٌ ‏"‏ ‏.‏\hadithno{3436}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Usamah bin Sharik said:“I saw the Bedouins asking the Prophet (ﷺ): ‘Is there any harm in such and such, is there any harm in such and such?’ He said to them: ‘O slaves of Allah! Allah has only made harm in that which transgresses the honor of one’s brother. That is what is sinful.’ They said: ‘O Messenger of Allah! Is there any sin if we do not seek treatment?’ He said: ‘Seek treatment, O slaves of Allah! For Allah does not create any disease but He also creates with it the cure, except for old age.’ They said: ‘O Messenger of Allah, what is the best thing that a person may be given?’ He said: ‘Good manners.’”}}
\hadithdefcmd{ibnmajah}{3437}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ أَبِي خِزَامَةَ، عَنْ أَبِي خِزَامَةَ، قَالَ سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَرَأَيْتَ أَدْوِيَةً نَتَدَاوَى بِهَا وَرُقًى نَسْتَرْقِي بِهَا وَتُقًى نَتَّقِيهَا هَلْ تَرُدُّ مِنْ قَدَرِ اللَّهِ شَيْئًا قَالَ ‏ "‏ هِيَ مِنْ قَدَرِ اللَّهِ ‏"‏ ‏.‏\hadithno{3437}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Khizamah said:“The Messenger of Allah (ﷺ) was asked: ‘Do you think that the medicines with which we treat ourselves, the Ruqyah by which we seek healing, and the means of protection that we seek, change the decree of Allah at all?’ He said: ‘They are part of the decree of Allah.’”}}
\hadithdefcmd{ibnmajah}{3438}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا أَنْزَلَ اللَّهُ دَاءً إِلاَّ أَنْزَلَ لَهُ دَوَاءً ‏"‏ ‏.‏\hadithno{3438}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah that the Prophet (ﷺ) said:“Allah does not send down any disease, but He also sends down the cure for it.”}}
\hadithdefcmd{ibnmajah}{3439}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالاَ حَدَّثَنَا أَبُو أَحْمَدَ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنَا عَطَاءٌ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا أَنْزَلَ اللَّهُ دَاءً إِلاَّ أَنْزَلَ لَهُ شِفَاءً ‏"‏ ‏.‏\hadithno{3439}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Allah does not send down any disease, but He also sends down the cure.”}}
\hadithdefcmd{ibnmajah}{3440}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا صَفْوَانُ بْنُ هُبَيْرَةَ، حَدَّثَنَا أَبُو مَكِينٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ عَادَ رَجُلاً فَقَالَ لَهُ ‏"‏ مَا تَشْتَهِي ‏"‏ ‏.‏ فَقَالَ أَشْتَهِي خُبْزَ بُرٍّ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ كَانَ عِنْدَهُ خُبْزُ بُرٍّ فَلْيَبْعَثْ إِلَى أَخِيهِ ‏"‏ ‏.‏ ثُمَّ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ إِذَا اشْتَهَى مَرِيضُ أَحَدِكُمْ شَيْئًا فَلْيُطْعِمْهُ ‏"‏ ‏.‏\hadithno{3440}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) visited a man (who was sick) and said to him:“What do you desire?” He said: “I want wheat bread.” The Prophet (ﷺ) said: “Whoever has wheat bread, let him send it to his brother.” Then the Prophet (ﷺ) said: “When a sick person among you desires something, give it to him.”}}
\hadithdefcmd{ibnmajah}{3441}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبُو يَحْيَى الْحِمَّانِيُّ، عَنِ الأَعْمَشِ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ دَخَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَلَى مَرِيضٍ يَعُودُهُ قَالَ ‏ "‏ أَتَشْتَهِي شَيْئًا أَتَشْتَهِي كَعْكًا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَطَلَبُوا لَهُ ‏.‏\hadithno{3441}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Prophet (ﷺ) went to visit a sick person, and said: ‘Do you want anything? Do you want cake?’ He said: ‘Yes.’ So they looked for some for him.”}}
\hadithdefcmd{ibnmajah}{3442}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ أَيُّوبَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي صَعْصَعَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، وَأَبُو دَاوُدَ قَالاَ حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ أَيُّوبَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ يَعْقُوبَ بْنِ أَبِي يَعْقُوبَ، عَنْ أُمِّ الْمُنْذِرِ بِنْتِ قَيْسٍ الأَنْصَارِيَّةِ، قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَمَعَهُ عَلِيُّ بْنُ أَبِي طَالِبٍ وَعَلِيٌّ نَاقِهٌ مِنْ مَرَضٍ وَلَنَا دَوَالِي مُعَلَّقَةٌ وَكَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَأْكُلُ مِنْهَا فَتَنَاوَلَ عَلِيٌّ لِيَأْكُلَ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مَهْ يَا عَلِيُّ إِنَّكَ نَاقِهٌ ‏"‏ ‏.‏ قَالَتْ فَصَنَعْتُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ سِلْقًا وَشَعِيرًا فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ يَا عَلِيُّ مِنْ هَذَا فَأَصِبْ فَإِنَّهُ أَنْفَعُ لَكَ ‏"‏ ‏.‏\hadithno{3442}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Umm Mundhir bint Qais Ansariyyah said:“The Messenger of Allah (ﷺ) entered upon us, and with him was ‘Ali bin Abu Talib, who had recently recovered from an illness. We had bunches of unripe dates hanging up, and the Prophet (ﷺ) was eating from them. ‘Ali reached out to eat some, and the Prophet (ﷺ) said to ‘Ali: ‘Stop, O ‘Ali! You have just recovered from an illness.’ I made some greens and barley for the Prophet (ﷺ), and the Prophet (ﷺ) said to ‘Ali: ‘O ‘Ali, eat some of this, for it is better for you.’”}}
\hadithdefcmd{ibnmajah}{3443}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ عَبْدِ الْحَمِيدِ بْنِ صَيْفِيٍّ، - مِنْ وَلَدِ صُهَيْبٍ - عَنْ أَبِيهِ، عَنْ جَدِّهِ، صُهَيْبٍ قَالَ قَدِمْتُ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَبَيْنَ يَدَيْهِ خُبْزٌ وَتَمْرٌ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ ادْنُ فَكُلْ ‏"‏ ‏.‏ فَأَخَذْتُ آكُلُ مِنَ التَّمْرِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ تَأْكُلُ تَمْرًا وَبِكَ رَمَدٌ ‏"‏ ‏.‏ قَالَ فَقُلْتُ إِنِّي أَمْضُغُ مِنْ نَاحِيَةٍ أُخْرَى ‏.‏ فَتَبَسَّمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3443}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Suhaib said:“I came to the Prophet (ﷺ) and in front of him there were some bread and dates. The Prophet (ﷺ) said: ‘Come and eat.’ So I started to eat some of the dates. Then the Prophet (ﷺ) said: ‘Are you eating dates when you have an inflammation in your eye?’ I said: ‘I am chewing from the other side.’ And the Messenger of Allah (ﷺ) smiled.”}}
\hadithdefcmd{ibnmajah}{3444}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا بَكْرُ بْنُ يُونُسَ بْنِ بُكَيْرٍ، عَنْ مُوسَى بْنِ عَلِيِّ بْنِ رَبَاحٍ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُكْرِهُوا مَرْضَاكُمْ عَلَى الطَّعَامِ وَالشَّرَابِ فَإِنَّ اللَّهَ يُطْعِمُهُمْ وَيَسْقِيهِمْ ‏"‏ ‏.‏\hadithno{3444}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Uqbah bin ‘Amir Al-Juhani that the Messenger of Allah (ﷺ) said:“Do not force your sick ones to eat or drink. Allah will feed them and give them to drink.”}}
\hadithdefcmd{ibnmajah}{3445}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا مُحَمَّدُ بْنُ السَّائِبِ بْنِ بَرَكَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا أَخَذَ أَهْلَهُ الْوَعْكُ أَمَرَ بِالْحَسَاءِ ‏.‏ قَالَتْ وَكَانَ يَقُولُ ‏ "‏ إِنَّهُ لَيَرْتُو فُؤَادَ الْحَزِينِ وَيَسْرُو عَنْ فُؤَادِ السَّقِيمِ كَمَا تَسْرُو إِحْدَاكُنَّ الْوَسَخَ عَنْ وَجْهِهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{3445}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“If any of his family members became ill, the Messenger of Allah (ﷺ) would order that some broth be made. And he would say: ‘It consoles the grieving heart and cleanses the ailing heart, as anyone of you cleanses her face of dirt with water.’”}}
\hadithdefcmd{ibnmajah}{3446}{حَدَّثَنَا عَلِيُّ بْنُ أَبِي الْخَصِيبِ، حَدَّثَنَا وَكِيعٌ، عَنْ أَيْمَنَ بْنِ نَابِلٍ، عَنِ امْرَأَةٍ، مِنْ قُرَيْشٍ يُقَالَ لَهَا كَلْثَمُ عَنْ عَائِشَةَ، قَالَتْ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ عَلَيْكُمْ بِالْبَغِيضِ النَّافِعِ التَّلْبِينَةِ ‏"‏ ‏.‏ يَعْنِي الْحَسَاءَ ‏.‏ قَالَتْ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا اشْتَكَى أَحَدٌ مِنْ أَهْلِهِ لَمْ تَزَلِ الْبُرْمَةُ عَلَى النَّارِ حَتَّى يَنْتَهِيَ أَحَدُ طَرَفَيْهِ ‏.‏ يَعْنِي يَبْرَأُ أَوْ يَمُوتُ ‏.‏\hadithno{3446}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said:“You should eat the beneficial thing that is unpleasant to eat: Talbinah,” meaning broth. If any member of the family of the Messenger of Allah (ﷺ) was sick, the cooking pot would remain on the fire until one of two things happened, either the person recovered or died}}
\hadithdefcmd{ibnmajah}{3447}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، وَمُحَمَّدُ بْنُ الْحَارِثِ الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُمَا أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ فِي الْحَبَّةِ السَّوْدَاءِ شِفَاءً مِنْ كُلِّ دَاءٍ إِلاَّ السَّامَ ‏"‏ ‏.‏ وَالسَّامُ الْمَوْتُ ‏.‏ وَالْحَبَّةُ السَّوْدَاءُ الشُّونِيزُ ‏.‏\hadithno{3447}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that he heard the Messenger of Allah (ﷺ) say:“In black seed there is healing for every disease, except the Sam.” "Sam means death. And black seed is Shuwniz}}
\hadithdefcmd{ibnmajah}{3448}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُثْمَانَ بْنِ عَبْدِ الْمَلِكِ، قَالَ سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ عَلَيْكُمْ بِهَذِهِ الْحَبَّةِ السَّوْدَاءِ فَإِنَّ فِيهَا شِفَاءً مِنْ كُلِّ دَاءٍ إِلاَّ السَّامَ ‏"‏ ‏.‏\hadithno{3448}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Uthman bin ‘Abdul-Malik said:“I heard Salim bin ‘Abdullah narrating from his father that the Messenger of Allah (ﷺ) said: ‘You should eat this black seed, for in it there is healing from every disease, except the Sam (death).’”}}
\hadithdefcmd{ibnmajah}{3449}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، أَنْبَأَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ خَالِدِ بْنِ سَعْدٍ، قَالَ خَرَجْنَا وَمَعَنَا غَالِبُ بْنُ أَبْجَرَ فَمَرِضَ فِي الطَّرِيقِ فَقَدِمْنَا الْمَدِينَةَ وَهُوَ مَرِيضٌ فَعَادَهُ ابْنُ أَبِي عَتِيقٍ وَقَالَ لَنَا عَلَيْكُمْ بِهَذِهِ الْحَبَّةِ السَّوْدَاءِ فَخُذُوا مِنْهَا خَمْسًا أَوْ سَبْعًا فَاسْحَقُوهَا ثُمَّ اقْطُرُوهَا فِي أَنْفِهِ بِقَطَرَاتِ زَيْتٍ فِي هَذَا الْجَانِبِ وَفِي هَذَا الْجَانِبِ فَإِنَّ عَائِشَةَ حَدَّثَتْهُمْ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ إِنَّ هَذِهِ الْحَبَّةَ السَّوْدَاءَ شِفَاءٌ مِنْ كُلِّ دَاءٍ إِلاَّ أَنْ يَكُونَ السَّامُ ‏"‏ ‏.‏ قُلْتُ وَمَا السَّامُ قَالَ ‏"‏ الْمَوْتُ ‏"‏ ‏.‏\hadithno{3449}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Khalid bin Sa’d said:“We went out and with us was Ghalib bin Abjar. He fell sick along the way, and when we came to Al-Madinah he was sick. Ibn Abu ‘Atiq came to visit him and said to us: ‘You should use this black seed. Take five or seven (seeds) and grind them to a powder, then drop them into his nose with drops of olive oil, on this side and on this side. For ‘Aishah narrated to them that she heard the Messenger of Allah (ﷺ) say: “This black seed is a healing for every disease, except the Sam.” I said: “What is the Sam?” He said: “Death.”}}
\hadithdefcmd{ibnmajah}{3450}{حَدَّثَنَا مَحْمُودُ بْنُ خِدَاشٍ، حَدَّثَنَا سَعِيدُ بْنُ زَكَرِيَّاءَ الْقُرَشِيُّ، حَدَّثَنَا الزُّبَيْرُ بْنُ سَعِيدٍ الْهَاشِمِيُّ، عَنْ عَبْدِ الْحَمِيدِ بْنِ سَالِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ لَعِقَ الْعَسَلَ ثَلاَثَ غَدَوَاتٍ كُلَّ شَهْرٍ لَمْ يُصِبْهُ عَظِيمٌ مِنَ الْبَلاَءِ ‏"‏ ‏.‏\hadithno{3450}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever eats honey three mornings each month, will not suffer any serious calamity.”}}
\hadithdefcmd{ibnmajah}{3451}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا عُمَرُ بْنُ سَهْلٍ، حَدَّثَنَا أَبُو حَمْزَةَ الْعَطَّارُ، عَنِ الْحَسَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أُهْدِيَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ عَسَلٌ فَقَسَمَ بَيْنَنَا لُعْقَةً لُعْقَةً فَأَخَذْتُ لُعْقَتِي ثُمَّ قُلْتُ يَا رَسُولَ اللَّهِ أَزْدَادُ أُخْرَى قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{3451}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“Some honey was given as a gift to the Prophet (ﷺ), and he shared among us spoonful by spoonful. I took my spoonful then I said: ‘O Messenger of Allah, can I have another?’ He said: ‘Yes.’”}}
\hadithdefcmd{ibnmajah}{3452}{حَدَّثَنَا عَلِيُّ بْنُ سَلَمَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عَلَيْكُمْ بِالشِّفَاءَيْنِ الْعَسَلِ وَالْقُرْآنِ ‏"‏ ‏.‏\hadithno{3452}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“You should take the two that bring healing: Honey and the Qur’an.”}}
\hadithdefcmd{ibnmajah}{3453}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ جَعْفَرِ بْنِ إِيَاسٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي سَعِيدٍ، وَجَابِرٍ، قَالاَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْكَمْأَةُ مِنَ الْمَنِّ وَمَاؤُهَا شِفَاءٌ لِلْعَيْنِ وَالْعَجْوَةُ مِنَ الْجَنَّةِ وَهِي شِفَاءٌ مِنَ الْجَنَّةَ ‏"‏ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرَّقِّيَّانِ، قَالاَ حَدَّثَنَا سَعِيدُ بْنُ مَسْلَمَةَ بْنِ هِشَامٍ، عَنِ الأَعْمَشِ، عَنْ جَعْفَرِ بْنِ إِيَاسٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ مِثْلَهُ ‏.‏\hadithno{3453}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa`eed and Jabir that the Messenger of Allah (ﷺ) said:“Truffles are a type of manna, and their water is a healing for eye (diseases). And the `Ajwah* are from Paradise, and they are healing for possession.”** Another chain from Abu Sa`eed from the Prophet (ﷺ) with similar wording}}
\hadithdefcmd{ibnmajah}{3454}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، سَمِعَ عَمْرَو بْنَ حُرَيْثٍ، يَقُولُ سَمِعْتُ سَعِيدَ بْنَ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، يُحَدِّثُ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّ ‏ "‏ الْكَمْأَةُ مِنَ الْمَنِّ الَّذِي أَنْزَلَ اللَّهُ عَلَى بَنِي إِسْرَائِيلَ وَمَاؤُهَا شِفَاءٌ لِلْعَيْنِ ‏"‏ ‏.‏\hadithno{3454}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{‘Amr bin Huraith said:“I heard Sa’eed bin Zaid bin ‘Amr bin Nufail narrating from the Prophet (ﷺ) that: ‘Truffles are a type of manna that Allah sent down to the Children of Israel, and their water is a healing for eye (diseases).’”}}
\hadithdefcmd{ibnmajah}{3455}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَبْدِ الصَّمَدِ، حَدَّثَنَا مَطَرٌ الْوَرَّاقُ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كُنَّا نَتَحَدَّثُ عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَكَرْنَا الْكَمْأَةَ فَقَالُوا هِيَ جُدَرِيُّ الأَرْضِ ‏.‏ فَنُمِيَ الْحَدِيثُ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ الْكَمْأَةُ مِنَ الْمَنِّ وَالْعَجْوَةُ مِنَ الْجَنَّةِ وَهِيَ شِفَاءٌ مِنَ السَّمِّ ‏"‏ ‏.‏\hadithno{3455}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“We used to narrate from the Messenger of Allah (ﷺ) and mention truffles, and they said: ‘(It is) the smallpox of the earth.’ When the Messenger of Allah (ﷺ) was told of what they were saying: he said: ‘Truffles are a type of manna, and the Ajwah are from Paradise, and they are a healing from poison.’”}}
\hadithdefcmd{ibnmajah}{3456}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا الْمُشْمَعِلُّ بْنُ إِيَاسٍ الْمُزَنِيُّ، حَدَّثَنِي عَمْرُو بْنُ سُلَيْمٍ، قَالَ سَمِعْتُ رَافِعَ بْنَ عَمْرٍو الْمُزَنِيَّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْعَجْوَةُ وَالصَّخْرَةُ مِنَ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ حَفِظْتُ الصَّخْرَةَ مِنْ فِيهِ ‏.‏\hadithno{3456}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Rafi’ bin ‘Amr Al-Muzani said:“I heard the Messenger of Allah (ﷺ) say: “Ajwah and the rock* are from Paradise.’”}}
\hadithdefcmd{ibnmajah}{3457}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ يُوسُفَ بْنِ سَرْجٍ الْفِرْيَابِيُّ، حَدَّثَنَا عَمْرُو بْنُ بَكْرٍ السَّكْسَكِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي عَبْلَةَ، قَالَ سَمِعْتُ أَبَا أُبَىٍّ ابْنَ أُمِّ حَرَامٍ، وَكَانَ، قَدْ صَلَّى مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ الْقِبْلَتَيْنِ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ عَلَيْكُمْ بِالسَّنَى وَالسَّنُّوتِ فَإِنَّ فِيهِمَا شِفَاءً مِنْ كُلِّ دَاءٍ إِلاَّ السَّامَ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا السَّامُ قَالَ ‏"‏ الْمَوْتُ ‏"‏ ‏.‏ قَالَ عَمْرٌو قَالَ ابْنُ أَبِي عَبْلَةَ السَّنُّوتُ الشِّبِتُّ ‏.‏ وَقَالَ آخَرُونَ بَلْ هُوَ الْعَسَلُ الَّذِي يَكُونُ فِي زِقَاقِ السَّمْنِ وَهُوَ قَوْلُ الشَّاعِرِ هُمُ السَّمْنُ بِالسَّنُّوتِ لاَ أَلْسَ فِيهِمُ وَهُمْ يَمْنَعُونَ جَارَهُمْ أَنْ يُقَرَّدَا\hadithno{3457}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibrahim bin Abu ‘Ablah said:“I heard Abu Ubayy bin Umm Haram, who had prayed with the Messenger of Allah (ﷺ) facing both the Qiblah, saying: ‘I heard the Messenger of Allah (ﷺ) say: “You should use senna and the Sannut, for in them there is healing for every disease, except the Sam.” It was said: “O Messenger of Allah, what is the Sam?” He said: “Death.” (One of the narrators) ‘Amr said: “Ibn Abu ‘Ablah said: the ‘Sannut is dill.” Others said: “Rather, it is honey that is kept in a skin (i.e., receptacle) used for ghee.”}}
\hadithdefcmd{ibnmajah}{3458}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا السَّرِيُّ بْنُ مِسْكِينٍ، حَدَّثَنَا ذُؤَادُ بْنُ عُلْبَةَ، عَنْ لَيْثٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ هَجَّرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَهَجَّرْتُ فَصَلَّيْتُ ثُمَّ جَلَسْتُ فَالْتَفَتَ إِلَىَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ اشِكَمَتْ دَرْدْ ‏"‏ ‏.‏ قُلْتُ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ قُمْ فَصَلِّ فَإِنَّ فِي الصَّلاَةِ شِفَاءً ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ الْقَطَّانُ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَصْرٍ، حَدَّثَنَا أَبُو سَلَمَةَ، حَدَّثَنَا ذُؤَادُ بْنُ عُلْبَةَ، فَذَكَرَ نَحْوَهُ وَقَالَ فِيهِ اشِكَمَتْ دَرْدْ ‏.‏ يَعْنِي تَشْتَكِي بَطْنَكَ بِالْفَارِسِيَّةِ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ حَدَّثَ بِهِ رَجُلٌ لأَهْلِهِ فَاسْتَعْدَوْا عَلَيْهِ ‏.‏\hadithno{3458}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) set out in the early morning and I did likewise. I prayed, then I sat. The Prophet (ﷺ) turned to me and said: ‘Do you have a stomach problem?’* I said: ‘Yes, O Messenger of Allah.’ He said: ‘Get up and pray, for in prayer there is healing.’” Another chain with similar wording. Abu `Abdullah said: A man narrated it to his people, then they were stirred up against him}}
\hadithdefcmd{ibnmajah}{3459}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ مُجَاهِدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الدَّوَاءِ الْخَبِيثِ ‏.‏ يَعْنِي السُّمَّ ‏.‏\hadithno{3459}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade treating illness with foul things (Khabith), meaning poison.”}}
\hadithdefcmd{ibnmajah}{3460}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ شَرِبَ سُمًّا فَقَتَلَ نَفْسَهُ فَهُوَ يَتَحَسَّاهُ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا ‏"‏ ‏.‏\hadithno{3460}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever drinks poison and kills himself, will be sipping it in the fire of Hell forever and ever.’”}}
\hadithdefcmd{ibnmajah}{3461}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ زُرْعَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مَوْلًى، لِمَعْمَرٍ التَّيْمِيِّ عَنْ مَعْمَرٍ التَّيْمِيِّ، عَنْ أَسْمَاءَ بِنْتِ عُمَيْسٍ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ بِمَاذَا كُنْتِ تَسْتَمْشِينَ ‏"‏ ‏.‏ قُلْتُ بِالشُّبْرُمِ قَالَ ‏"‏ حَارٌّ جَارٌّ ‏"‏ ‏.‏ ثُمَّ اسْتَمْشَيْتُ بِالسَّنَى ‏.‏ فَقَالَ ‏"‏ لَوْ كَانَ شَىْءٌ يَشْفِي مِنَ الْمَوْتِ كَانَ السَّنَى وَالسَّنَى شِفَاءٌ مِنَ الْمَوْتِ ‏"‏ ‏.‏\hadithno{3461}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Asma’ bint ‘Umais said:“The Messenger of Allah (ﷺ) said to me: ‘What do you use as a laxative?’ I said: ‘The Shubrum (spurge – Euphorb).’ He said: (It is) hot and powerful.’ Then I used senna as a laxative and he said: ‘If anything were to cure death, it would be senna. Senna is a cure for death.’”}}
\hadithdefcmd{ibnmajah}{3462}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، قَالَتْ دَخَلْتُ بِابْنٍ لِي عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَقَدْ أَعْلَقْتُ عَلَيْهِ مِنَ الْعُذْرَةِ فَقَالَ ‏ "‏ عَلاَمَ تَدْغَرْنَ أَوْلاَدَكُنَّ بِهَذَا الْعِلاَقِ عَلَيْكُمْ بِهَذَا الْعُودِ الْهِنْدِيِّ فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ يُسْعَطُ بِهِ مِنَ الْعُذْرَةِ وَيُلَدُّ بِهِ مِنْ ذَاتِ الْجَنْبِ ‏"‏ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏ قَالَ يُونُسُ أَعْلَقْتُ يَعْنِي غَمَزْتُ ‏.‏\hadithno{3462}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Umm Qais bint Mihsan said:“I brought a son of mine to the Prophet (ﷺ), and I had pressed on an area of his throat due to tonsillitis. He said: ‘Why do you poke your children with this pressing?’ You should use this aloeswood, for in it there are seven cures. It should be inhaled for pustules in the throat, and given in the side of the mouth for pleurisy.” (Another chain) from Umm Qais bint Mihsan, from the Prophet (ﷺ) with similar wording}}
\hadithdefcmd{ibnmajah}{3463}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَرَاشِدُ بْنُ سَعِيدٍ الرَّمْلِيُّ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، حَدَّثَنَا أَنَسُ بْنُ سِيرِينَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ شِفَاءُ عِرْقِ النَّسَا أَلْيَةُ شَاةٍ أَعْرَابِيَّةٍ تُذَابُ ثُمَّ تُجَزَّأُ ثَلاَثَةَ أَجْزَاءٍ ثُمَّ يُشْرَبُ عَلَى الرِّيقِ فِي كُلِّ يَوْمٍ جُزْءٌ ‏"‏ ‏.‏\hadithno{3463}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik said:“I heard the Messenger of Allah (ﷺ) saying: ‘The cure for sciatica is the fat from the tail of a Bedouin sheep (or wild sheep), which should be melted and divided into three parts, one part to be taken each day on an empty stomach.’”}}
\hadithdefcmd{ibnmajah}{3464}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ جُرِحَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ أُحُدٍ وَكُسِرَتْ رَبَاعِيَتُهُ وَهُشِمَتِ الْبَيْضَةُ عَلَى رَأْسِهِ فَكَانَتْ فَاطِمَةُ تَغْسِلُ الدَّمَ عَنْهُ وَعَلِيٌّ يَسْكُبُ عَلَيْهِ الْمَاءَ بِالْمِجَنِّ فَلَمَّا رَأَتْ فَاطِمَةُ أَنَّ الْمَاءَ لاَ يَزِيدُ الدَّمَ إِلاَّ كَثْرَةً أَخَذَتْ قِطْعَةَ حَصِيرٍ فَأَحْرَقَتْهَا حَتَّى إِذَا صَارَ رَمَادًا أَلْزَمَتْهُ الْجُرْحَ فَاسْتَمْسَكَ الدَّمُ ‏.‏\hadithno{3464}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sahl bin Sa’d As-Sa’idi said:“The Messenger of Allah (ﷺ) was wounded on the Day of Uhud. His molar was broken and his helmet was crushed on his head. Fatimah was washing the blood from him and ‘Ali was pouring water on him from a shield. When Fatimah realized that the water was only making the bleeding worse, she took a piece of a mat and burnt it, and when it had turned to ashes, she applied it to the wound to stop the bleeding}}
\hadithdefcmd{ibnmajah}{3465}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ الْمُهَيْمِنِ بْنِ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ إِنِّي لأَعْرِفُ يَوْمَ أُحُدٍ مَنْ جَرَحَ وَجْهَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَمَنْ كَانَ يُرْقِئُ الْكَلْمَ مِنْ وَجْهِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَيُدَاوِيهِ وَمَنْ يَحْمِلُ الْمَاءَ فِي الْمِجَنِّ وَبِمَا دُووِيَ بِهِ الْكَلْمُ حَتَّى رَقَأَ ‏.‏ قَالَ أَمَّا مَنْ كَانَ يَحْمِلُ الْمَاءَ فِي الْمِجَنِّ فَعَلِيٌّ وَأَمَّا مَنْ كَانَ يُدَاوِي الْكَلْمَ فَفَاطِمَةُ أَحْرَقَتْ لَهُ حِينَ لَمْ يَرْقَأْ قِطْعَةَ حَصِيرٍ خَلَقٍ فَوَضَعَتْ رَمَادَهُ عَلَيْهِ فَرَقَأَ الْكَلْمُ ‏.‏\hadithno{3465}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdul-Muhaimin bin ‘Abbas bin Sahl bin Sa’d As- Sa’idi, from his father, that his grandfather said:“On the Day of Uhud, I recognized the one who wounded the face of the Messenger of Allah (ﷺ), the one who was washing the blood from the face of the Messenger of Allah (ﷺ) and treating him, and the one who was bringing the water in a shield, and with what the wound was treated until the bleeding stopped. The one who was carrying the water in the shield was ‘Ali. The one who was treating the wound was Fatimah. When the bleeding would not stop, she burned a piece of a worn out mat and applied the ashes to it (the wound), then the bleeding stopped}}
\hadithdefcmd{ibnmajah}{3466}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَرَاشِدُ بْنُ سَعِيدٍ الرَّمْلِيُّ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَطَبَّبَ وَلَمْ يُعْلَمْ مِنْهُ طِبٌّ قَبْلَ ذَلِكَ فَهُوَ ضَامِنٌ ‏"‏ ‏.‏\hadithno{3466}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) said: ‘Whoever gives medical treatment, with no prior knowledge of medicine, is responsible (for any harm done).’”}}
\hadithdefcmd{ibnmajah}{3467}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَيْمُونٍ، حَدَّثَنِي أَبِي، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ نَعَتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ ذَاتِ الْجَنْبِ وَرْسًا وَقُسْطًا وَزَيْتًا يُلَدُّ بِهِ ‏.‏\hadithno{3467}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Zaid bin Arqam said:“The Messenger of Allah (ﷺ) prescribed Wars (memecyclon tinctorium), Indian aloeswood and olive oil for pleurisy, to be administered through the side of the mouth.”}}
\hadithdefcmd{ibnmajah}{3468}{حَدَّثَنَا أَبُو طَاهِرٍ، أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ، وَابْنُ، سَمْعَانَ عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ عَلَيْكُمْ بِالْعُودِ الْهِنْدِيِّ - يَعْنِي بِهِ الْكُسْتَ - فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ مِنْهَا ذَاتُ الْجَنْبِ ‏"‏ ‏.‏ قَالَ ابْنُ سَمْعَانَ فِي الْحَدِيثِ ‏"‏ فَإِنَّ فِيهِ شِفَاءً مِنْ سَبْعَةِ أَدْوَاءٍ مِنْهَا ذَاتُ الْجَنْبِ ‏"‏ ‏.‏\hadithno{3468}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umm Qais bint Mihsan said:“The Messenger of Allah (ﷺ) said: ‘You should use Indian aloeswood for it contains seven cures, including (a cure for) pleurisy.’”}}
\hadithdefcmd{ibnmajah}{3469}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ حَفْصِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ذُكِرَتِ الْحُمَّى عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَسَبَّهَا رَجُلٌ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَسُبَّهَا فَإِنَّهَا تَنْفِي الذُّنُوبَ كَمَا تَنْفِي النَّارُ خَبَثَ الْحَدِيدِ ‏"‏ ‏.‏\hadithno{3469}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“Mention of fever was made in the presence of the Messenger of Allah (ﷺ), and a man cursed it. The Prophet (ﷺ) said: ‘Do not curse it, for it erases sin as fire removes filth from iron.’”}}
\hadithdefcmd{ibnmajah}{3470}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ إِسْمَاعِيلَ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي صَالِحٍ الأَشْعَرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ عَادَ مَرِيضًا وَمَعَهُ أَبُو هُرَيْرَةَ مِنْ وَعْكٍ كَانَ بِهِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَبْشِرْ فَإِنَّ اللَّهَ يَقُولُ هِيَ نَارِي أُسَلِّطُهَا عَلَى عَبْدِيَ الْمُؤْمِنِ فِي الدُّنْيَا لِتَكُونَ حَظَّهُ مِنَ النَّارِ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3470}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) visited a sick person, due to an illness that he was suffering from and Abu Hurairah was with him. The Messenger of Allah (ﷺ) said:“Be of good cheer, for Allah says: ‘It is My fire which I have causes to overwhelm My believing slave in this world, to be his share of the Fire in the Hereafter.”}}
\hadithdefcmd{ibnmajah}{3471}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{3471}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said:“Fever is from the heat of the Hell-fire, so cool it down with water.”}}
\hadithdefcmd{ibnmajah}{3472}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ إِنَّ شِدَّةَ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{3472}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) said:“Intense fever is from the heat of Hell-fire, so cool it down with water.”}}
\hadithdefcmd{ibnmajah}{3473}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُصْعَبُ بْنُ الْمِقْدَامِ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏ فَدَخَلَ عَلَى ابْنٍ لِعَمَّارٍ فَقَالَ ‏"‏ اكْشِفِ الْبَاسْ رَبَّ النَّاسْ إِلَهَ النَّاسْ ‏"‏ ‏.‏\hadithno{3473}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Rafi’ bin Khadij said:“I heard the Prophet (ﷺ) say: ‘Fever is from the heat of the Hell-fire, so cool it down with water.’ He entered upon a son of ‘Ammar and said: ‘Take away the harm, O Lord of mankind, O God of mankind.’”}}
\hadithdefcmd{ibnmajah}{3474}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا كَانَتْ تُؤْتَى بِالْمَرْأَةِ الْمَوْعُوكَةِ فَتَدْعُو بِالْمَاءِ فَتَصُبُّهُ فِي جَيْبِهَا وَتَقُولُ إِنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ ابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِنَّهَا مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{3474}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Asma’ bint Abu Bakr that a woman suffering from fever would be brought to her, and she would call for water and pour it onto the neck of her garment. She said:The Prophet (ﷺ) said: “Cool it down with water,” and he said: “It is from the heat of Hell-fire.”}}
\hadithdefcmd{ibnmajah}{3475}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْحُمَّى كِيرٌ مِنْ كِيرِ جَهَنَّمَ فَنَحُّوهَا عَنْكُمْ بِالْمَاءِ الْبَارِدِ ‏"‏ ‏.‏\hadithno{3475}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Fever is one of the bellows of Hell, so avert it from yourselves with cold water.”}}
\hadithdefcmd{ibnmajah}{3476}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنْ كَانَ فِي شَىْءٍ مِمَّا تَدَاوَوْنَ بِهِ خَيْرٌ فَالْحِجَامَةُ ‏"‏ ‏.‏\hadithno{3476}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“If there is any good in any of the remedies you use, it is in cupping.”}}
\hadithdefcmd{ibnmajah}{3477}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا زِيَادُ بْنُ الرَّبِيعِ، حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا مَرَرْتُ لَيْلَةَ أُسْرِيَ بِي بِمَلإٍ مِنَ الْمَلاَئِكَةِ إِلاَّ كُلُّهُمْ يَقُولُ لِي عَلَيْكَ يَا مُحَمَّدُ بِالْحِجَامَةِ ‏"‏ ‏.‏\hadithno{3477}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“On the night on which I was taken on the Night Journey (Isra’), I did not pass by any group of angels but all of them said to me: ‘O Muhammad, you should use cupping.’”}}
\hadithdefcmd{ibnmajah}{3478}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نِعْمَ الْعَبْدُ الْحَجَّامُ يَذْهَبُ بِالدَّمِ وَيُخِفُّ الصُّلْبَ وَيَجْلُو الْبَصَرَ ‏"‏ ‏.‏\hadithno{3478}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) said: ‘What a good slave is the cupper. He takes away the blood, reduces pressure on the spine, and improves the eyesight.’”}}
\hadithdefcmd{ibnmajah}{3479}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا كَثِيرُ بْنُ سُلَيْمٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مَرَرْتُ لَيْلَةَ أُسْرِيَ بِي بِمَلإٍ إِلاَّ قَالُوا يَا مُحَمَّدُ مُرْ أُمَّتَكَ بِالْحِجَامَةِ ‏"‏ ‏.‏\hadithno{3479}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik said:“The Messenger of Allah (ﷺ) said: ‘On the night on which I was taken on the Night Journey (Isra’), I did not pass by any group (of angels) but they said to me: “O Muhammad, tell your nation to use cupping.”}}
\hadithdefcmd{ibnmajah}{3480}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ ـ صلى الله عليه وسلم ـ اسْتَأْذَنَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْحِجَامَةِ فَأَمَرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَبَا طَيْبَةَ أَنْ يَحْجُمَهَا ‏.‏ وَقَالَ حَسِبْتُ أَنَّهُ كَانَ أَخَاهَا مِنَ الرَّضَاعَةِ أَوْ غُلاَمًا لَمْ يَحْتَلِمْ ‏.‏\hadithno{3480}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that Umm Salamah, the wife of the Prophet (ﷺ), asked the Messenger of Allah (ﷺ) for permission to be cupped, and the Prophet (ﷺ) told Abu Taibah to cup her}}
\hadithdefcmd{ibnmajah}{3481}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي عَلْقَمَةُ بْنُ أَبِي عَلْقَمَةَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ الأَعْرَجَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ ابْنَ بُحَيْنَةَ، يَقُولُ احْتَجَمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِلَحْىِ جَمَلٍ وَهُوَ مُحْرِمٌ وَسْطَ رَأْسِهِ ‏.‏\hadithno{3481}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{‘Abdur-Rahman Al-A’raj said:“I heard ‘Abdullah bin Buhainah say: ‘The Messenger of Allah (ﷺ) was cupped in Lahyi Jamal,* in the middle of his head, while he was a Muhrim.”}}
\hadithdefcmd{ibnmajah}{3482}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ سَعْدٍ الإِسْكَافِ، عَنِ الأَصْبَغِ بْنِ نُبَاتَةَ، عَنْ عَلِيٍّ، قَالَ نَزَلَ جِبْرِيلُ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ بِحِجَامَةِ الأَخْدَعَيْنِ وَالْكَاهِلِ ‏.‏\hadithno{3482}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“Jibra’il came down to the Prophet (ﷺ) with (the recommendation of) cupping in the two veins at the side of the neck and the base of the neck.”}}
\hadithdefcmd{ibnmajah}{3483}{حَدَّثَنَا عَلِيُّ بْنُ أَبِي الْخَصِيبِ، حَدَّثَنَا وَكِيعٌ، عَنْ جَرِيرِ بْنِ حَازِمٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ احْتَجَمَ فِي الأَخْدَعَيْنِ وَعَلَى الْكَاهِلِ ‏.‏\hadithno{3483}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) was cupped in the two veins at theside of the neck and the base of the neck}}
\hadithdefcmd{ibnmajah}{3484}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ابْنُ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ أَبِي كَبْشَةَ الأَنْمَارِيِّ، أَنَّهُ حَدَّثَهُ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَحْتَجِمُ عَلَى هَامَتِهِ وَبَيْنَ كَتِفَيْهِ وَيَقُولُ ‏ "‏ مَنْ أَهْرَاقَ مِنْهُ هَذِهِ الدِّمَاءَ فَلاَ يَضُرُّهُ أَنْ لاَ يَتَدَاوَى بِشَىْءٍ لِشَىْءٍ ‏"‏ ‏.‏\hadithno{3484}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Kabshah Al-Anmari that the Prophet (ﷺ) used to be cupped on his head and between his shoulders, and he said:“Whoever lets blood from these places, it does not matter if he does not seek treatment for anything else.”}}
\hadithdefcmd{ibnmajah}{3485}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ سَقَطَ مِنْ فَرَسِهِ عَلَى جِذْعٍ فَانْفَكَّتْ قَدَمُهُ ‏.‏ قَالَ وَكِيعٌ يَعْنِي أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ احْتَجَمَ عَلَيْهَا مِنْ وَثْءٍ ‏.‏\hadithno{3485}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) fell from his horse onto the truck of a palm tree and dislocated his foot. (One of the narrators) Waki’ said:“Meaning that the Prophet (ﷺ) was cupped because of that for bruising.”}}
\hadithdefcmd{ibnmajah}{3486}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عُثْمَانُ بْنُ مَطَرٍ، عَنْ زَكَرِيَّا بْنِ مَيْسَرَةَ، عَنِ النَّهَّاسِ بْنِ قَهْمٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَرَادَ الْحِجَامَةَ فَلْيَتَحَرَّ سَبْعَةَ عَشَرَ أَوْ تِسْعَةَ عَشَرَ أَوْ إِحْدَى وَعِشْرِينَ وَلاَ يَتَبَيَّغْ بِأَحَدِكُمُ الدَّمُ فَيَقْتُلَهُ ‏"‏ ‏.‏\hadithno{3486}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Whoever wants to be cupped, let him seek out the seventeenth, nineteenth or twenty-first (of the month); and let none of you allow his blood to rage so that it kills him.”}}
\hadithdefcmd{ibnmajah}{3487}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عُثْمَانُ بْنُ مَطَرٍ، عَنِ الْحَسَنِ بْنِ أَبِي جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ يَا نَافِعُ قَدْ تَبَيَّغَ بِيَ الدَّمُ فَالْتَمِسْ لِي حَجَّامًا وَاجْعَلْهُ رَفِيقًا إِنِ اسْتَطَعْتَ وَلاَ تَجْعَلْهُ شَيْخًا كَبِيرًا وَلاَ صَبِيًّا صَغِيرًا فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْحِجَامَةُ عَلَى الرِّيقِ أَمْثَلُ وَفِيهِ شِفَاءٌ وَبَرَكَةٌ وَتَزِيدُ فِي الْعَقْلِ وَفِي الْحِفْظِ فَاحْتَجِمُوا عَلَى بَرَكَةِ اللَّهِ يَوْمَ الْخَمِيسِ وَاجْتَنِبُوا الْحِجَامَةَ يَوْمَ الأَرْبِعَاءِ وَالْجُمُعَةِ وَالسَّبْتِ وَيَوْمَ الأَحَدِ تَحَرِّيًا وَاحْتَجِمُوا يَوْمَ الاِثْنَيْنِ وَالثُّلاَثَاءِ فَإِنَّهُ الْيَوْمُ الَّذِي عَافَى اللَّهُ فِيهِ أَيُّوبَ مِنَ الْبَلاَءِ وَضَرَبَهُ بِالْبَلاَءِ يَوْمَ الأَرْبِعَاءِ فَإِنَّهُ لاَ يَبْدُو جُذَامٌ وَلاَ بَرَصٌ إِلاَّ يَوْمَ الأَرْبِعَاءِ أَوْ لَيْلَةَ الأَرْبِعَاءِ ‏"‏ ‏.‏\hadithno{3487}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“O Nafi’! The blood is boiling in me, find me a cupper, but let it be someone gentle if you can, not an old man or a young boy. For I heard the Messenger of Allah (ﷺ) say: ‘Cupping on an empty stomach is better, and in it there is healing and blessing, and it increases one’s intellect and memory. So have yourselves cupped for the blessing of Allah on Thursdays, and avoid cupping on Wednesdays, Fridays, Saturdays and Sundays. Have yourselves cupped on Mondays and Tuesdays, for that is the day on which Allah relieved Ayyub of Calamity, and He inflicted calamity upon him on a Wednesday, and leprosy and leucoderma only appear on Wednesdays, or on the night of Wednesday.”}}
\hadithdefcmd{ibnmajah}{3488}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عِصْمَةَ، عَنْ سَعِيدِ بْنِ مَيْمُونٍ، عَنْ نَافِعٍ، قَالَ قَالَ ابْنُ عُمَرَ يَا نَافِعُ تَبَيَّغَ بِيَ الدَّمُ فَأْتِنِي بِحَجَّامٍ وَاجْعَلْهُ شَابًّا وَلاَ تَجْعَلْهُ شَيْخًا وَلاَ صَبِيًّا ‏.‏ قَالَ وَقَالَ ابْنُ عُمَرَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْحِجَامَةُ عَلَى الرِّيقِ أَمْثَلُ وَهِيَ تَزِيدُ فِي الْعَقْلِ وَتَزِيدُ فِي الْحِفْظِ وَتَزِيدُ الْحَافِظَ حِفْظًا فَمَنْ كَانَ مُحْتَجِمًا فَيَوْمَ الْخَمِيسِ عَلَى اسْمِ اللَّهِ وَاجْتَنِبُوا الْحِجَامَةَ يَوْمَ الْجُمُعَةِ وَيَوْمَ السَّبْتِ وَيَوْمَ الأَحَدِ وَاحْتَجِمُوا يَوْمَ الاِثْنَيْنِ وَالثُّلاَثَاءِ وَاجْتَنِبُوا الْحِجَامَةَ يَوْمَ الأَرْبِعَاءِ فَإِنَّهُ الْيَوْمُ الَّذِي أُصِيبَ فِيهِ أَيُّوبُ بِالْبَلاَءِ وَمَا يَبْدُو جُذَامٌ وَلاَ بَرَصٌ إِلاَّ فِي يَوْمِ الأَرْبِعَاءِ أَوْ لَيْلَةِ الأَرْبِعَاءِ ‏"‏ ‏.‏\hadithno{3488}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Nafi’ said:“Ibn ‘Umar said: ‘O Nafi’! The blood is boiling in me. Bring me a cupper and let him be a young man, not an old man or a boy.’ Ibn ‘Umar said: ‘I heard the Messenger of Allah (ﷺ) say: “Cupping on an empty stomach is better, and it increases one’s intellect and memory. And it increases the memory of one who has a good memory so whoever wants to be cupped, (let him do it) on a Thursday, in the Name of Allah. Avoid cupping on Fridays, Saturdays and Sundays. Have yourselves cupped on Mondays and Tuesdays, and avoid cupping on Wednesdays, for that is the day on which the calamity befell Ayyub, and leprosy and leucoderma only appear on Wednesday or the night of Wednesday.”}}
\hadithdefcmd{ibnmajah}{3489}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ لَيْثٍ، عَنْ مُجَاهِدٍ، عَنْ عَقَّارِ بْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنِ اكْتَوَى أَوِ اسْتَرْقَى فَقَدْ بَرِئَ مِنَ التَّوَكُّلِ ‏"‏ ‏.‏\hadithno{3489}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Aqqar bin Al-Mughirah from his father that the Prophet (ﷺ) said:“Whoever seeks treatment by cauterization, or with Ruqyah, then he had absolved himself of reliance upon Allah.”}}
\hadithdefcmd{ibnmajah}{3490}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ مَنْصُورٍ، وَيُونُسَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْكَىِّ فَاكْتَوَيْتُ فَمَا أَفْلَحْتُ وَلاَ أَنْجَحْتُ ‏.‏\hadithno{3490}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Imran bin Husain said:“The Messenger of Allah (ﷺ) forbade cauterization. I had myself cauterized and I have not prospered or succeeded.”}}
\hadithdefcmd{ibnmajah}{3491}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا مَرْوَانُ بْنُ شُجَاعٍ، حَدَّثَنَا سَالِمٌ الأَفْطَسُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏ "‏ الشِّفَاءُ فِي ثَلاَثٍ شَرْبَةِ عَسَلٍ وَشَرْطَةِ مِحْجَمٍ وَكَيَّةٍ بِنَارٍ وَأَنْهَى أُمَّتِي عَنِ الْكَىِّ ‏"‏ ‏.‏ رَفَعَهُ ‏.‏\hadithno{3491}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Healing is in three things: A drink of honey, the glass of the cupper, and cauterizing with fire, but I forbid my nation to use cauterization.” And he attributed it to the Prophet (ﷺ)}}
\hadithdefcmd{ibnmajah}{3492}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، غُنْدَرٌ حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ سَعْدِ بْنِ زُرَارَةَ الأَنْصَارِيُّ، قَالَ سَمِعْتُ عَمِّي، يَحْيَى - وَمَا أَدْرَكْتُ رَجُلاً مِنَّا بِهِ شَبِيهًا يُحَدِّثُ النَّاسَ أَنَّ سَعْدَ بْنَ زُرَارَةَ - وَهُوَ جَدُّ مُحَمَّدٍ مِنْ قِبَلِ أُمِّهِ أَنَّهُ أَخَذَهُ وَجَعٌ فِي حَلْقِهِ يُقَالُ لَهُ الذُّبْحَةُ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ لأُبْلِغَنَّ أَوْ لأُبْلِيَنَّ فِي أَبِي أُمَامَةَ عُذْرًا ‏"‏ ‏.‏ فَكَوَاهُ بِيَدِهِ فَمَاتَ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مِيتَةَ سُوءٍ لِلْيَهُودِ يَقُولُونَ أَفَلاَ دَفَعَ عَنْ صَاحِبِهِ ‏.‏ وَمَا أَمْلِكُ لَهُ وَلاَ لِنَفْسِي شَيْئًا ‏"‏ ‏.‏\hadithno{3492}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammad bin ‘Abdur-Rahman bin Sa’d bin Zurarah Al-Ansari said:“I heard my paternal uncle Yahya – and I have not seen a man among us like him – tell the people that Sa'd bin Zurarah, who was the grandfather of Muhammad through his mother, was suffering from pain in his throat, known as croup. The Prophet (ﷺ) said: ‘I shall do my best for Abu Umamah.’ Such that I will be excused (i.e., free of blame if he is not healed). And he cauterized him with his own hand, but he died. The Prophet (ﷺ) said: ‘May the Jews be doomed! They will say: “Why could he not avert death from his Companions?” But I have no power to do anything for him or for my own self.’”}}
\hadithdefcmd{ibnmajah}{3493}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ مَرِضَ أُبَىُّ بْنُ كَعْبٍ مَرَضًا فَأَرْسَلَ إِلَيْهِ النَّبِيُّ طَبِيبًا فَكَوَاهُ عَلَى أَكْحَلِهِ ‏.‏\hadithno{3493}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“Ubayy bin Ka’b fell sick, and the Prophet (ﷺ) sent a doctor to him who cauterized him on his medical arm vein.”}}
\hadithdefcmd{ibnmajah}{3494}{حَدَّثَنَا عَلِيُّ بْنُ أَبِي الْخَصِيبِ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَوَى سَعْدَ بْنَ مُعَاذٍ فِي أَكْحَلِهِ مَرَّتَيْنِ ‏.‏\hadithno{3494}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) cauterized Sa’d bin Mu’adh on his medial arm vein, twice}}
\hadithdefcmd{ibnmajah}{3495}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنِي عُثْمَانُ بْنُ عَبْدِ الْمَلِكِ، قَالَ سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عَلَيْكُمْ بِالإِثْمِدِ فَإِنَّهُ يَجْلُو الْبَصَرَ وَيُنْبِتُ الشَّعَرَ ‏"‏ ‏.‏\hadithno{3495}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Salim bin ‘Abdullah narrated that his father said:“The Messenger of Allah (ﷺ) said: ‘You should use antimony, for it improves the eyesight and makes the hair (eyelashes) grow.’”}}
\hadithdefcmd{ibnmajah}{3496}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ عَلَيْكُمْ بِالإِثْمِدِ عِنْدَ النَّوْمِ فَإِنَّهُ يَجْلُو الْبَصَرَ وَيُنْبِتُ الشَّعَرَ ‏"‏ ‏.‏\hadithno{3496}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“I heard the Messenger of Allah (ﷺ) say: ‘You should use antimony when you go to sleep, for it improves the eyesight and makes the hair (eyelashes) grow.’”}}
\hadithdefcmd{ibnmajah}{3497}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنِ ابْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَيْرُ أَكْحَالِكُمُ الإِثْمِدُ يَجْلُو الْبَصَرَ وَيُنْبِتُ الشَّعَرَ ‏"‏ ‏.‏\hadithno{3497}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“The best of your kohl is antimony, for it improves the eyesight and makes the hair (eyelashes) grow.”}}
\hadithdefcmd{ibnmajah}{3498}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الصَّبَّاحِ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ حُصَيْنٍ الْحِمْيَرِيِّ، عَنْ أَبِي سَعْدِ الْخَيْرِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنِ اكْتَحَلَ فَلْيُوتِرْ مَنْ فَعَلَ فَقَدْ أَحْسَنَ وَمَنْ لاَ فَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3498}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever applies kohl, let him do it an odd number of times. Whoever does that has done well, and whoever does not, it does not matter.”}}
\hadithdefcmd{ibnmajah}{3499}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ عَبَّادِ بْنِ مَنْصُورٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتْ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ مُكْحُلَةٌ يَكْتَحِلُ مِنْهَا ثَلاَثًا فِي كُلِّ عَيْنٍ ‏.‏\hadithno{3499}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) had a kohl container from which he would apply kohl three times, to each eye.”}}
\hadithdefcmd{ibnmajah}{3500}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَنْبَأَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ الْحَضْرَمِيِّ، عَنْ طَارِقِ بْنِ سُوَيْدٍ الْحَضْرَمِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ بِأَرْضِنَا أَعْنَابًا نَعْتَصِرُهَا فَنَشْرَبُ مِنْهَا قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ فَرَاجَعْتُهُ قُلْتُ إِنَّا نَسْتَشْفِي بِهِ لِلْمَرِيضِ ‏.‏ قَالَ ‏"‏ إِنَّ ذَلِكَ لَيْسَ بِشِفَاءٍ وَلَكِنَّهُ دَاءٌ ‏"‏ ‏.‏\hadithno{3500}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Tariq bin Suwaid Al-Hadrami said:“I said: ‘O Messenger of Allah, in our land there are grapes which we squeeze (to make wine). Can we drink from it?’ He said: ‘No.’ I repeated the question and said: ‘We treat the sick with it.’ He said: ‘That is not a cure, it is a disease.’”}}
\hadithdefcmd{ibnmajah}{3501}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ عُتْبَةَ بْنِ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ، حَدَّثَنَا عَلِيُّ بْنُ ثَابِتٍ، حَدَّثَنَا سَعَّادُ بْنُ سُلَيْمَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَيْرُ الدَّوَاءِ الْقُرْآنُ ‏"‏ ‏.‏\hadithno{3501}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Ali that the Messenger of Allah (ﷺ) said:“The best remedy is the Qur’an.”}}
\hadithdefcmd{ibnmajah}{3502}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا فَائِدٌ، مَوْلَى عُبَيْدِ اللَّهِ بْنِ عَلِيِّ بْنِ أَبِي رَافِعٍ حَدَّثَنِي مَوْلاَىَ، عُبَيْدُ اللَّهِ حَدَّثَتْنِي جَدَّتِي، سَلْمَى أُمُّ رَافِعٍ مَوْلاَةُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَتْ كَانَ لاَ يُصِيبُ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَرْحَةٌ وَلاَ شَوْكَةٌ إِلاَّ وَضَعَ عَلَيْهِ الْحِنَّاءَ ‏.‏\hadithno{3502}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Salma Umm Rafi’, the freed slave woman of the Messenger of Allah (ﷺ), said:“The Prophet (ﷺ) did not suffer any injury or thorn- prick but he would apply henna to it.”}}
\hadithdefcmd{ibnmajah}{3503}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، أَنَّ نَاسًا، مِنْ عُرَيْنَةَ قَدِمُوا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَاجْتَوَوُا الْمَدِينَةَ فَقَالَ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْ خَرَجْتُمْ إِلَى ذَوْدٍ لَنَا فَشَرِبْتُمْ مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏ ‏.‏ فَفَعَلُوا ‏.‏\hadithno{3503}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that some people from ‘Urainah came to the Messenger of Allah (ﷺ) but they were averse to the climate of Al- Madinah. He (ﷺ) said:“Why don’t you go out to a flock of camels of ours, and drink their milk and urine.” And they did that}}
\hadithdefcmd{ibnmajah}{3504}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ خَالِدٍ، عَنْ أَبِي سَلَمَةَ، حَدَّثَنِي أَبُو سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ فِي أَحَدِ جَنَاحَىِ الذُّبَابِ سُمٌّ وَفِي الآخَرِ شِفَاءٌ فَإِذَا وَقَعَ فِي الطَّعَامِ فَامْقُلُوهُ فِيهِ فَإِنَّهُ يُقَدِّمُ السُّمَّ وَيُؤَخِّرُ الشِّفَاءَ ‏"‏ ‏.‏\hadithno{3504}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa’eed narrated that the Messenger of Allah (ﷺ) said:“On one of the wings of a fly there is a poison and on the other is the cure. If it falls into the food, then dip it into it, for it puts the poison first and holds back the cure.”}}
\hadithdefcmd{ibnmajah}{3505}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مُسْلِمُ بْنُ خَالِدٍ، عَنْ عُتْبَةَ بْنِ مُسْلِمٍ، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا وَقَعَ الذُّبَابُ فِي شَرَابِكُمْ فَلْيَغْمِسْهُ فِيهِ ثُمَّ لْيَطْرَحْهُ فَإِنَّ فِي أَحَدِ جَنَاحَيْهِ دَاءً وَفِي الآخَرِ شِفَاءً ‏"‏ ‏.‏\hadithno{3505}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“If a fly falls into your drink, dip it into it then throw it away, for on one of its wings is a disease and on the other is a cure.”}}
\hadithdefcmd{ibnmajah}{3506}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ أُمَيَّةَ بْنِ هِنْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْعَيْنُ حَقٌّ ‏"‏ ‏.‏\hadithno{3506}\hadithgrade{Al-Albani: Sahih Mutawatir; Muhammad Fouad Abd al-Baqi: Sahih Mutawatir; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amir bin Rabi’ah, from his father, that the Prophet (ﷺ) said:“The evil eye is real.”}}
\hadithdefcmd{ibnmajah}{3507}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ الْجُرَيْرِيِّ، عَنْ مُضَارِبِ بْنِ حَزْنٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْعَيْنُ حَقٌّ ‏"‏ ‏.‏\hadithno{3507}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘The evil eye is real.”}}
\hadithdefcmd{ibnmajah}{3508}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو هِشَامٍ الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَبِي وَاقِدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اسْتَعِيذُوا بِاللَّهِ فَإِنَّ الْعَيْنَ حَقٌّ ‏"‏ ‏.‏\hadithno{3508}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:‘Seek refuge with Allah, for the evil eye is real.”}}
\hadithdefcmd{ibnmajah}{3509}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، قَالَ مَرَّ عَامِرُ بْنُ رَبِيعَةَ بِسَهْلِ بْنِ حُنَيْفٍ وَهُوَ يَغْتَسِلُ فَقَالَ لَمْ أَرَ كَالْيَوْمِ وَلاَ جِلْدَ مُخَبَّأَةٍ ‏.‏ فَمَا لَبِثَ أَنْ لُبِطَ بِهِ فَأُتِيَ بِهِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقِيلَ لَهُ أَدْرِكْ سَهْلاً صَرِيعًا ‏.‏ قَالَ ‏"‏ مَنْ تَتَّهِمُونَ بِهِ ‏"‏ ‏.‏ قَالُوا عَامِرَ بْنَ رَبِيعَةَ ‏.‏ قَالَ ‏"‏ عَلاَمَ يَقْتُلُ أَحَدُكُمْ أَخَاهُ إِذَا رَأَى أَحَدُكُمْ مِنْ أَخِيهِ مَا يُعْجِبُهُ فَلْيَدْعُ لَهُ بِالْبَرَكَةِ ‏"‏ ‏.‏ ثُمَّ دَعَا بِمَاءٍ فَأَمَرَ عَامِرًا أَنْ يَتَوَضَّأَ فَيَغْسِلَ وَجْهَهُ وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ وَرُكْبَتَيْهِ وَدَاخِلَةَ إِزَارِهِ وَأَمَرَهُ أَنْ يَصُبَّ عَلَيْهِ ‏.‏ قَالَ سُفْيَانُ قَالَ مَعْمَرٌ عَنِ الزُّهْرِيِّ وَأَمَرَهُ أَنْ يَكْفَأَ الإِنَاءَ مِنْ خَلْفِهِ ‏.‏\hadithno{3509}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Umamah bin Sahl bin Hunaif said:“ ‘Amir bin Rabi’ah passed by Sahl bin Hunaif when he was having a bath, and said: ‘I have never seen such beautiful skin.’ Straightaway, he (Sahl) fell to the ground. He was brought to the Prophet (ﷺ) and it was said: ‘Sahl has had a fit.’ He said: ‘Whom do you accuse with regard to him?’ They said: “ ‘Amir bin Rabi’ah.’ They said: ‘Why would anyone of you kill his brother? If he sees something that he likes, then let him pray for blessing for him.’ Then he called for water, and he told ‘Amir to perform ablution, then he washed his face and his arms up to the elbows, his knees and inside his lower garment, then he told him to pour the water over him.”}}
\hadithdefcmd{ibnmajah}{3510}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عُرْوَةَ بْنِ عَامِرٍ، عَنْ عُبَيْدِ بْنِ رِفَاعَةَ الزُّرَقِيِّ، قَالَ قَالَتْ أَسْمَاءُ يَا رَسُولَ اللَّهِ إِنَّ بَنِي جَعْفَرٍ تُصِيبُهُمُ الْعَيْنُ فَأَسْتَرْقِي لَهُمْ قَالَ ‏ "‏ نَعَمْ فَلَوْ كَانَ شَىْءٌ سَابَقَ الْقَدَرَ سَبَقَتْهُ الْعَيْنُ ‏"‏ ‏.‏\hadithno{3510}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Ubaid bin Rifa’ah Az-Zuraqi said:“Asma’ said: ‘O Messenger of Allah! The children of Ja’far have been afflicted by the evil eye, shall I recite Ruqyah* for them?’ He said: ‘Yes, for if anything were to overtake the Divine decree it would be the evil eye.’”}}
\hadithdefcmd{ibnmajah}{3511}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، عَنْ عَبَّادٍ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَتَعَوَّذُ مِنْ عَيْنِ الْجَانِّ وَأَعْيُنِ الإِنْسِ فَلَمَّا نَزَلَتِ الْمُعَوِّذَتَانِ أَخَذَهُمَا وَتَرَكَ مَا سِوَى ذَلِكَ ‏.‏\hadithno{3511}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) used to seek refuge from the evil eye of the jinn and of mankind. When the Mu’awwidhatain* were revealed, he started to recite them and stopped reciting anything else.”}}
\hadithdefcmd{ibnmajah}{3512}{حَدَّثَنَا عَلِيُّ بْنُ أَبِي الْخَصِيبِ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، وَمِسْعَرٍ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَمَرَهَا أَنْ تَسْتَرْقِيَ مِنَ الْعَيْنِ ‏.‏\hadithno{3512}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) commanded her to recite Ruqyah to treat the evil eye}}
\hadithdefcmd{ibnmajah}{3513}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، عَنْ أَبِي جَعْفَرٍ الرَّازِيِّ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ بُرَيْدَةَ بْنِ الْحُصَيْبِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ رُقْيَةَ إِلاَّ مِنْ عَيْنٍ أَوْ حُمَةٍ ‏"‏ ‏.‏\hadithno{3513}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Buraidah that the Messenger of Allah (ﷺ) said:“There is no Ruqyah except for the evil eye or from the sting of a scorpion.”}}
\hadithdefcmd{ibnmajah}{3514}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ عُمَارَةَ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، أَنَّ خَالِدَةَ بِنْتَ أَنَسٍ أُمَّ بَنِي حَزْمٍ السَّاعِدِيَّةَ، جَاءَتْ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَعَرَضَتْ عَلَيْهِ الرُّقَى فَأَمَرَهَا بِهَا ‏.‏\hadithno{3514}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It as narrated from Abu Bakr bin Muhammad that Khalidah bint Anas, the mother of Banu Hazm As-Sa’idiyyah, came to the Prophet (ﷺ) and recited a Ruqyah to him, and he told her to use it}}
\hadithdefcmd{ibnmajah}{3515}{حَدَّثَنَا عَلِيُّ بْنُ أَبِي الْخَصِيبِ، حَدَّثَنَا يَحْيَى بْنُ عِيسَى، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ كَانَ أَهْلُ بَيْتٍ مِنَ الأَنْصَارِ يُقَالُ لَهُمْ آلُ عَمْرِو بْنِ حَزْمٍ يَرْقُونَ مِنَ الْحُمَةِ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَدْ نَهَى عَنِ الرُّقَى فَأَتَوْهُ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّكَ قَدْ نَهَيْتَ عَنِ الرُّقَى وَإِنَّا نَرْقِي مِنَ الْحُمَةِ ‏.‏ فَقَالَ لَهُمُ ‏"‏ اعْرِضُوا عَلَىَّ ‏"‏ ‏.‏ فَعَرَضُوهَا عَلَيْهِ فَقَالَ ‏"‏ لاَ بَأْسَ بِهَذِهِ هَذِهِ مَوَاثِيقُ ‏"‏ ‏.‏\hadithno{3515}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“There was a family among the Ansar, called Al ‘Amr bin Hazm, who used to recite Ruqyah for the scorpion sting, but the Messenger of Allah (ﷺ) forbade Ruqyah. They came to him and said: ‘O Messenger of Allah! You have forbidden Ruqyah, but we recite Ruqyah against the scorpion’s sting.’ He said to them: ‘Recite it to me.’ So they recited it to him, and he said: ‘There is nothing wrong with this, this is confirmed.’”}}
\hadithdefcmd{ibnmajah}{3516}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَخَّصَ فِي الرُّقْيَةِ مِنَ الْحُمَةِ وَالْعَيْنِ وَالنَّمْلَةِ ‏.‏\hadithno{3516}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) allowed Ruqyah for the scorpion’s sting, the evil eye, and Namlah (sores or small pustules ulcers or sores on a person’s sides)}}
\hadithdefcmd{ibnmajah}{3517}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ رَخَّصَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الرُّقْيَةِ مِنَ الْحَيَّةِ وَالْعَقْرَبِ ‏.‏\hadithno{3517}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) allowed Ruqyah for snakebites and scorpion stings.”}}
\hadithdefcmd{ibnmajah}{3518}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ بَهْرَامَ، حَدَّثَنَا عُبَيْدُ اللَّهِ الأَشْجَعِيُّ، عَنْ سُفْيَانَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَدَغَتْ عَقْرَبٌ رَجُلاً فَلَمْ يَنَمْ لَيْلَتَهُ فَقِيلَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ إِنَّ فُلاَنًا لَدَغَتْهُ عَقْرَبٌ فَلَمْ يَنَمْ لَيْلَتَهُ ‏.‏ فَقَالَ ‏ "‏ أَمَا إِنَّهُ لَوْ قَالَ حِينَ أَمْسَى أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ - مَا ضَرَّهُ لَدْغُ عَقْرَبٍ حَتَّى يُصْبِحَ ‏"‏ ‏.‏\hadithno{3518}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“A scorpion stung a man and he did not sleep all the night. It was said to the Prophet (ﷺ): ‘So- and-so was stung by a scorpion and he did not sleep all the night.’ He said: ‘If he had said, last night: A’udhu bikalimatil-lahit-tammati min sharri ma khalaq (I seek refuge in the Perfect Words of Allah from the evil of that which He has created), the scorpion sting would not have harmed him, until morning.’”}}
\hadithdefcmd{ibnmajah}{3519}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، حَدَّثَنِي أَبُو بَكْرِ بْنُ عَمْرِو بْنِ حَزْمٍ، عَنْ عَمْرِو بْنِ حَزْمٍ، قَالَ عَرَضْتُ النَّهْشَةَ مِنَ الْحَيَّةِ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَمَرَ بِهَا ‏.‏\hadithno{3519}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Amr bin Hazm said:“I recited the Ruqyah for snakebite to the Messenger of Allah (ﷺ), or it was recited to him, and he commanded that it be used.”}}
\hadithdefcmd{ibnmajah}{3520}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا أَتَى الْمَرِيضَ فَدَعَا لَهُ قَالَ ‏ "‏ أَذْهِبِ الْبَاسْ رَبَّ النَّاسْ وَاشْفِ أَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏\hadithno{3520}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“When the Messenger of Allah (ﷺ) came to a sick person, he would make supplication for him, and would say: Adhhibil-bas, Rabban-nas, washfi Antash-Shafi, la shifa’a illa shifa’uka shifa’an la yughadiru saqama (Take away the pain, O Lord of mankind, and grant healing, for You are the Healer, and there is no healing but Your healing that leaves no trace of sickness).’”}}
\hadithdefcmd{ibnmajah}{3521}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ رَبِّهِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ مِمَّا يَقُولُ لِلْمَرِيضِ بِبُزَاقِهِ بِإِصْبَعِهِ ‏ "‏ بِسْمِ اللَّهِ بِتُرْبَةِ أَرْضِنَا بِرِيقَةِ بَعْضِنَا لِيُشْفَى سَقِيمُنَا بِإِذْنِ رَبِّنَا ‏"‏ ‏.‏\hadithno{3521}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Aishah that one of the things that the Prophet (ﷺ) used to say for the sick person, with saliva on his finger (dipped in dust), was:“Bismillah, turbatu ardina, biriqati ba’dina, liyushfa saqimuna. Bi’dhni Rabbina (In the Name of Allah, the dust of our land mixed with the saliva of one of us, to cure our sick one by the permission of our Lord).”}}
\hadithdefcmd{ibnmajah}{3522}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ كَعْبٍ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ الثَّقَفِيِّ، أَنَّهُ قَالَ قَدِمْتُ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَبِي وَجَعٌ قَدْ كَادَ يُبْطِلُنِي فَقَالَ لِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ اجْعَلْ يَدَكَ الْيُمْنَى عَلَيْهِ وَقُلْ بِسْمِ اللَّهِ أَعُوذُ بِعِزَّةِ اللَّهِ وَقُدْرَتِهِ مِنْ شَرِّ مَا أَجِدُ وَأُحَاذِرُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏ فَقُلْتُ ذَلِكَ فَشَفَانِيَ اللَّهُ ‏.‏\hadithno{3522}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Uthman bin Abul-‘As Thaqafi said:“I came to the Prophet (ﷺ) and I was suffering pain that was killing me. The Prophet (ﷺ) said to me: ‘Put your right hand on it and say: Bismillah, a’udhu bi’izzatil-lahi wa qudratihi min sharri ma ajidu wa uhadhiru. (In the Name of Allah, I seek refuge in the might and power of Allah from the evil of what I feel and what I fear),” seven times.’ I said that, and Allah healed me.”}}
\hadithdefcmd{ibnmajah}{3523}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ جِبْرَائِيلَ، أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا مُحَمَّدُ اشْتَكَيْتَ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ بِسْمِ اللَّهِ أَرْقِيكَ مِنْ كُلِّ شَىْءٍ يُؤْذِيكَ مِنْ شَرِّ كُلِّ نَفْسٍ أَوْ عَيْنٍ أَوْ حَاسِدٍ اللَّهُ يَشْفِيكَ بِسْمِ اللَّهِ أَرْقِيكَ ‏.‏\hadithno{3523}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa’eed that Jibra’il came to the Prophet (ﷺ) and said:“O Muhammad, you are ill. He said: ‘Yes.’ He said: Bismillahi arqika, min kulli shay’in yu’dhika, min sharri kulli nafsin aw ‘aynin aw hasidin. Allahu yashfika, bismillahi arqika (In the Name of Allah I perform Ruqyah for you, from everything that is harming you, from the evil of every soul or envious eye, may Allah heal you. In the Name of Allah I perform Ruqyah for you)}}
\hadithdefcmd{ibnmajah}{3524}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَحَفْصُ بْنُ عُمَرَ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ زِيَادِ بْنِ ثُوَيْبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَعُودُنِي فَقَالَ لِي ‏"‏ أَلاَ أَرْقِيكَ بِرُقْيَةٍ جَاءَنِي بِهَا جِبْرَائِيلُ ‏"‏ ‏.‏ قُلْتُ بِأَبِي وَأُمِّي بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ بِسْمِ اللَّهِ أَرْقِيكَ وَاللَّهُ يَشْفِيكَ مِنْ كُلِّ دَاءٍ فِيكَ مِنْ شَرِّ النَّفَّاثَاتِ فِي الْعُقَدِ وَمِنْ شَرِّ حَاسِدٍ إِذَا حَسَدَ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{3524}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) came to visit me (when I was sick), and said to me: ‘Shall I not recite for you a Ruqyah that Jibra’il brought to me?’ I said: ‘May my father and mother be ransomed for you! Yes, O Messenger of Allah!’ He said: Bismillah arqika, wallahu yashfika, min kulli da’in fika, min sharrin- naffathati fil-‘uqad, wa min sharri hasidin idha hasad (In the Name of Allah I perform Ruqyah for you, from every disease that is in you, and from the evil of those who (practice witchcraft when they) blow in the knots, and from the evil of the envier when he envies), three times.”}}
\hadithdefcmd{ibnmajah}{3525}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ بْنِ هِشَامٍ الْبَغْدَادِيُّ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا أَبُو عَامِرٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ مِنْهَالٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُعَوِّذُ الْحَسَنَ وَالْحُسَيْنَ يَقُولُ ‏"‏ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ كُلِّ شَيْطَانٍ وَهَامَّةٍ وَمِنْ كُلِّ عَيْنٍ لاَمَّةٍ ‏"‏ ‏.‏ قَالَ ‏"‏ وَكَانَ أَبُونَا إِبْرَاهِيمُ يَعُوِّذُ بِهَا إِسْمَاعِيلَ وَإِسْحَاقَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ إِسْمَاعِيلَ وَيَعْقُوبَ ‏"‏ ‏.‏ وَهَذَا حَدِيثُ وَكِيعٍ ‏.‏\hadithno{3525}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) used to seek refuge for Hasan and Husain and say: A’udhu bi kalimatil-lahil- tammati, min kulli shaitanin wa hammah, wa min kulli ‘aynin lammah (I seek refuge for you both in the Perfect Words of Allah, from every devil and every poisonous reptile, and from every evil eye).’ And he would say: ‘Thus Ibrahim used to seek refuge with Allah for Isma’il and Ishaq,’ or he said: ‘for Isma’il and Ya’qub.’”}}
\hadithdefcmd{ibnmajah}{3526}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا إِبْرَاهِيمُ الأَشْهَلِيُّ، عَنْ دَاوُدَ بْنِ حُصَيْنٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُعَلِّمُهُمْ مِنَ الْحُمَّى وَمِنَ الأَوْجَاعِ كُلِّهَا أَنْ يَقُولُوا ‏"‏ بِسْمِ اللَّهِ الْكَبِيرِ أَعُوذُ بِاللَّهِ الْعَظِيمِ مِنْ شَرِّ عِرْقٍ نَعَّارٍ وَمِنْ شَرِّ حَرِّ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عَامِرٍ أَنَا أُخَالِفُ النَّاسَ فِي هَذَا أَقُولُ يَعَّارٍ ‏.‏ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنِي إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ بْنِ أَبِي حَبِيبَةَ الأَشْهَلِيُّ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ وَقَالَ ‏"‏ مِنْ شَرِّ عِرْقٍ نَعَّارٍ ‏"‏ ‏.‏\hadithno{3526}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that, for fever and all kinds of pain, the Prophet (ﷺ) used to teach them to say:“Bismillahil-kabir, a’udhu billahil-‘Azim min sharri ‘irqin na’ar wa, min sharri harrin- nar (In the Name of Allah the Great, I seek refuge with Allah the Almighty from the evil of a vein gushing (with blood) and the evil of the heat of the Fire.” (One of the narrators) Abu `Ammar said: “I differed with the people on this, I said: ‘Screaming.’” Another chain from Ibn `Abbas, from the Prophet (ﷺ) with similar wording, and he said: “From the evil of a vein screaming (with blood).”}}
\hadithdefcmd{ibnmajah}{3527}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا أَبِي، عَنِ ابْنِ ثَوْبَانَ، عَنْ عُمَيْرٍ، أَنَّهُ سَمِعَ جُنَادَةَ بْنَ أَبِي أُمَيَّةَ، قَالَ سَمِعْتُ عُبَادَةَ بْنَ الصَّامِتِ، يَقُولُ أَتَى جِبْرَائِيلُ عَلَيْهِ السَّلاَمُ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَهُوَ يُوعَكُ فَقَالَ بِسْمِ اللَّهِ أَرْقِيكَ مِنْ كُلِّ شَىْءٍ يُؤْذِيكَ مِنْ حَسَدِ حَاسِدٍ وَمِنْ كُلِّ عَيْنٍ اللَّهُ يَشْفِيكَ ‏.‏\hadithno{3527}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Umair that he heard Junadah bin Abu Umayyah say:“I heard ‘Ubadah bin Samit say: ‘Jibra’il (as) came to the Prophet (ﷺ) when he was suffering from fever and said: ‘Bismillahi arqika, min kulli shay’in yu’dhika, min hasadi hasidin, wa min kulli ‘aynin, Allahu yashfika (In the Name of Allah I perform Ruqyah for you, from everything that is harming you; from the envy of the envier and from every evil eye, may Allah heal you).’”}}
\hadithdefcmd{ibnmajah}{3528}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَنْفِثُ فِي الرُّقْيَةِ ‏.‏\hadithno{3528}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) used to blow when performing Ruqyah}}
\hadithdefcmd{ibnmajah}{3529}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، قَالَ حَدَّثَنَا مَعْنُ بْنُ عِيسَى، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، قَالاَ حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا اشْتَكَى يَقْرَأُ عَلَى نَفْسِهِ الْمُعَوِّذَاتِ وَيَنْفِثُ فَلَمَّا اشْتَدَّ وَجَعُهُ كُنْتُ أَقْرَأُ عَلَيْهِ وَأَمْسَحُ بِيَدِهِ رَجَاءَ بَرَكَتِهَا ‏.‏\hadithno{3529}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Aishah:“Whenever the Prophet (ﷺ) fell ill, he would recite the Mu’awwidhat and blow, and when his pain grew worse, I would recite over him and wipe his hand over him, hoping for its blessing.”}}
\hadithdefcmd{ibnmajah}{3530}{حَدَّثَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الرَّقِّيُّ، حَدَّثَنَا مُعَمَّرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بِشْرٍ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ يَحْيَى بْنِ الْجَزَّارِ، عَنِ ابْنِ أُخْتِ، زَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ عَنْ زَيْنَبَ، قَالَتْ كَانَتْ عَجُوزٌ تَدْخُلُ عَلَيْنَا تَرْقِي مِنَ الْحُمْرَةِ وَكَانَ لَنَا سَرِيرٌ طَوِيلُ الْقَوَائِمِ وَكَانَ عَبْدُ اللَّهِ إِذَا دَخَلَ تَنَحْنَحَ وَصَوَّتَ فَدَخَلَ يَوْمًا فَلَمَّا سَمِعَتْ صَوْتَهُ احْتَجَبَتْ مِنْهُ فَجَاءَ فَجَلَسَ إِلَى جَانِبِي فَمَسَّنِي فَوَجَدَ مَسَّ خَيْطٍ فَقَالَ مَا هَذَا فَقُلْتُ رُقًى لِي فِيهِ مِنَ الْحُمْرَةِ فَجَذَبَهُ وَقَطَعَهُ فَرَمَى بِهِ وَقَالَ لَقَدْ أَصْبَحَ آلُ عَبْدِ اللَّهِ أَغْنِيَاءَ عَنِ الشِّرْكِ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ إِنَّ الرُّقَى وَالتَّمَائِمَ وَالتِّوَلَةَ شِرْكٌ ‏"‏ ‏.‏ قُلْتُ فَإِنِّي خَرَجْتُ يَوْمًا فَأَبْصَرَنِي فُلاَنٌ فَدَمَعَتْ عَيْنِي الَّتِي تَلِيهِ فَإِذَا رَقَيْتُهَا سَكَنَتْ دَمْعَتُهَا وَإِذَا تَرَكْتُهَا دَمَعَتْ ‏.‏ قَالَ ذَاكِ الشَّيْطَانُ إِذَا أَطَعْتِيهِ تَرَكَكِ وَإِذَا عَصَيْتِيهِ طَعَنَ بِإِصْبَعِهِ فِي عَيْنِكِ وَلَكِنْ لَوْ فَعَلْتِ كَمَا فَعَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ خَيْرًا لَكِ وَأَجْدَرَ أَنْ تَشْفِينَ تَنْضَحِينَ فِي عَيْنِكِ الْمَاءَ وَتَقُولِينَ ‏"‏ أَذْهِبِ الْبَاسْ رَبَّ النَّاسْ اشْفِ أَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏\hadithno{3530}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Zainab said:“There was an old woman who used to enter upon us and perform Ruqyah from erysipelas: Contagious disease which causes fever and leaves a red coloration of the skin. We had a bed with long legs, and when ‘Abdullah entered he would clear his throat and make noise. He entered one day and when she heard his voice she veiled herself from him. He came and sat beside me, and touched me, and he found a sting. He said: ‘What is this?’ I said: ‘An amulet against erysipelas.’ He pulled it, broke it and threw it away, and said: ‘The family of ‘Abdullah has no need of polytheism.’ I heard the Messenger of Allah (ﷺ) say: “Ruqyah (i.e., which consist of the names of idols and devils etc.), amulets and Tiwalah (charms) are polytheism.’” “I said: ‘I went out one day and so-and-so looked at me, and my eye began to water on the side nearest him. When I recited Ruqyah for it, it stopped, but if I did not recite Ruqyah it watered again.’ He said: ‘That is Satan, if you obey him he leaves you alone but if you disobey him he pokes you with his finger in your eye. But if you do what the Messenger of Allah (ﷺ) used to do, that will be better for you and more effective in healing. Sprinkle water in your eye and say: Adhhibil-bas Rabban-nas, washfi Antash-Shafi, la shifa’a illa shafi’uka, shafi’an la yughadiru saqaman (Take away the pain, O Lord of mankind, and grant healing, for You are the Healer, and there is no healing but Your healing that leaves no trace of sickness).’”}}
\hadithdefcmd{ibnmajah}{3531}{حَدَّثَنَا عَلِيُّ بْنُ أَبِي الْخَصِيبِ، حَدَّثَنَا وَكِيعٌ، عَنْ مُبَارَكٍ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَأَى رَجُلاً فِي يَدِهِ حَلْقَةٌ مِنْ صُفْرٍ فَقَالَ ‏"‏ مَا هَذِهِ الْحَلْقَةُ ‏"‏ ‏.‏ قَالَ هَذِهِ مِنَ الْوَاهِنَةِ ‏.‏ قَالَ ‏"‏ انْزِعْهَا فَإِنَّهَا لاَ تَزِيدُكَ إِلاَّ وَهْنًا ‏"‏ ‏.‏\hadithno{3531}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Imran bin Husain that the Prophet (ﷺ) saw a man with a brass ring on his hand. He said:“What is this ring?” He said: “It is for Wahinah.”* He said: “Take it off, for it will only increase you in weakness.”}}
\hadithdefcmd{ibnmajah}{3532}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، عَنْ أُمِّ جُنْدَبٍ، قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَمَى جَمْرَةَ الْعَقَبَةِ مِنْ بَطْنِ الْوَادِي يَوْمَ النَّحْرِ ثُمَّ انْصَرَفَ وَتَبِعَتْهُ امْرَأَةٌ مِنْ خَثْعَمٍ وَمَعَهَا صَبِيٌّ لَهَا بِهِ بَلاَءٌ لاَ يَتَكَلَّمُ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ هَذَا ابْنِي وَبَقِيَّةُ أَهْلِي وَإِنَّ بِهِ بَلاَءً لاَ يَتَكَلَّمُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ ائْتُونِي بِشَىْءٍ مِنْ مَاءٍ ‏"‏ ‏.‏ فَأُتِيَ بِمَاءٍ فَغَسَلَ يَدَيْهِ وَمَضْمَضَ فَاهُ ثُمَّ أَعْطَاهَا فَقَالَ ‏"‏ اسْقِيهِ مِنْهُ وَصُبِّي عَلَيْهِ مِنْهُ وَاسْتَشْفِي اللَّهَ لَهُ ‏"‏ ‏.‏ قَالَتْ فَلَقِيتُ الْمَرْأَةَ فَقُلْتُ لَوْ وَهَبْتِ لِي مِنْهُ ‏.‏ فَقَالَتْ إِنَّمَا هُوَ لِهَذَا الْمُبْتَلَى ‏.‏ قَالَتْ فَلَقِيتُ الْمَرْأَةَ مِنَ الْحَوْلِ فَسَأَلْتُهَا عَنِ الْغُلاَمِ فَقَالَتْ بَرَأَ وَعَقَلَ عَقْلاً لَيْسَ كَعُقُولِ النَّاسِ ‏.‏\hadithno{3532}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Jundub said:“I saw the Messenger of Allah (ﷺ) stoning the ‘Aqabah Pillar from the bottom of the valley on the Day of Sacrifice, then he went away. A woman from Khath’am followed him, and with her was a son of hers who had been afflicted, he could not speak. She said: ‘O Messenger of Allah! This is my son, and he is all I have left of my family. He has been afflicted and cannot speak.’ The Messenger of Allah (ﷺ) said: ‘Bring me some water.’ So it was brought, and he washed his hands and rinsed out his mouth. Then he gave it to her and said: ‘Give him some to drink, and pour some over him, and seek Allah’s healing for him.’” She (Umm Jundub) said: “I met that woman and said: ‘Why don’t you give me some?’ She said: ‘It is only for the sick one.’ I met that woman one year later and asked her about the boy. She said: ‘He recovered and became (very) smart, not like the rest of the people.’”}}
\hadithdefcmd{ibnmajah}{3533}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ عُتْبَةَ بْنِ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ حَدَّثَنَا عَلِيُّ بْنُ ثَابِتٍ حَدَّثَنَا مُعَّادُ بْنُ سُلَيْمَانَ عَنْ أَبِي إِسْحَقَ عَنْ الْحَارِثِ عَنْ عَلِيٍّ رَضِيَ اللَّهُ عَنْهُ قَالَ قَالَ رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ خَيْرُ الدَّوَاءِ الْقُرْآنُ\hadithno{3533}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif}\hadithtrans{It was narrated from ‘Ali that the Messenger of Allah (ﷺ) said:“The best remedy is the Qur’an.”}}
\hadithdefcmd{ibnmajah}{3534}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِقَتْلِ ذِي الطُّفْيَتَيْنِ فَإِنَّهُ يَلْتَمِسُ الْبَصَرَ وَيُصِيبُ الْحَبَلَ ‏.‏ يَعْنِي حَيَّةً خَبِيثَةً ‏.‏\hadithno{3534}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) enjoined killing Dhit-Tufytain* for it takes away the sight and causes miscarriage.” *That means a wicked snake}}
\hadithdefcmd{ibnmajah}{3535}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ اقْتُلُوا الْحَيَّاتِ وَاقْتُلُوا ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يَلْتَمِسَانِ الْبَصَرَ وَيُسْقِطَانِ الْحَبَلَ ‏"‏ ‏.‏\hadithno{3535}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{it was narrated from Salim, from his father, that the Messenger of Allah (ﷺ) said:“Kill snakes, and kill Dhit-Tufytain* and the Abtar**, for they take away the sight and cause miscarriage.” *A snake that has two white stripes on its back. **A snake with a short or mutilated tail}}
\hadithdefcmd{ibnmajah}{3536}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُعْجِبُهُ الْفَأْلُ الْحَسَنُ وَيَكْرَهُ الطِّيَرَةَ ‏.‏\hadithno{3536}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) used to like good signs and hate bad omens.”}}
\hadithdefcmd{ibnmajah}{3537}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَأُحِبُّ الْفَأْلَ الصَّالِحَ ‏"‏ ‏.‏\hadithno{3537}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:“The Prophet (ﷺ) said: ‘There is no ‘Adwa* and no omen, but I like Al-Fa’l As-Salih.”}}
\hadithdefcmd{ibnmajah}{3538}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ، عَنْ عِيسَى بْنِ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الطِّيَرَةُ شِرْكٌ وَمَا مِنَّا إِلاَّ وَلَكِنَّ اللَّهَ يُذْهِبُهُ بِالتَّوَكُّلِ ‏"‏ ‏.‏\hadithno{3538}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“The omen is polytheistic deed and anyone of us may think he sees an omen but Allah will dispel it by means of relying upon Him.”}}
\hadithdefcmd{ibnmajah}{3539}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَلاَ هَامَةَ وَلاَ صَفَرَ ‏"‏ ‏.‏\hadithno{3539}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“There is no ‘Adwa, no omen, no Hamah and no Safar.”}}
\hadithdefcmd{ibnmajah}{3540}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي جَنَابٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَلاَ هَامَةَ ‏"‏ ‏.‏ فَقَامَ إِلَيْهِ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ الْبَعِيرُ يَكُونُ بِهِ الْجَرَبُ فَتَجْرَبُ بِهِ الإِبِلُ ‏.‏ قَالَ ‏"‏ ذَلِكَ الْقَدَرُ فَمَنْ أَجْرَبَ الأَوَّلَ ‏"‏ ‏.‏\hadithno{3540}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘There is no ‘Adwa, no omen, and no Hamah.’ A man stood up and said: ‘O Messenger of Allah, what if a camel has mange and another camel gets mange from it?’ He said: ‘That is the Divine decree. Who causes the mange in the first one?’”}}
\hadithdefcmd{ibnmajah}{3541}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يُورِدُ الْمُمْرِضُ عَلَى الْمُصِحِّ ‏"‏ ‏.‏\hadithno{3541}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A man with sick camels should not let them graze or drink alongside healthy ones.”}}
\hadithdefcmd{ibnmajah}{3542}{حَدَّثَنَا أَبُو بَكْرٍ، وَمُجَاهِدُ بْنُ مُوسَى، وَمُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، قَالُوا حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُفَضَّلُ بْنُ فَضَالَةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَخَذَ بِيَدِ رَجُلٍ مَجْذُومٍ فَأَدْخَلَهَا مَعَهُ فِي الْقَصْعَةِ ثُمَّ قَالَ ‏ "‏ كُلْ ثِقَةً بِاللَّهِ وَتَوَكُّلاً عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{3542}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) took the hand of a leper and made him eat with him, and said:“Eat, with trust in Allah and reliance upon Allah.”}}
\hadithdefcmd{ibnmajah}{3543}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنِ ابْنِ أَبِي الزِّنَادِ، ح وَحَدَّثَنَا عَلِيُّ بْنُ أَبِي الْخَصِيبِ، حَدَّثَنَا وَكِيعٌ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، جَمِيعًا عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُمِّهِ، فَاطِمَةَ بِنْتِ الْحُسَيْنِ عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تُدِيمُوا النَّظَرَ إِلَى الْمَجْذُومِينَ ‏"‏ ‏.‏\hadithno{3543}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said:“Do not keep looking at those who have leprosy.”}}
\hadithdefcmd{ibnmajah}{3544}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ رَجُلٍ، مِنْ آلِ الشَّرِيدِ يُقَالُ لَهُ عَمْرٌو عَنْ أَبِيهِ قَالَ كَانَ فِي وَفْدِ ثَقِيفٍ رَجُلٌ مَجْذُومٌ فَأَرْسَلَ إِلَيْهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ ارْجِعْ فَقَدْ بَايَعْنَاكَ ‏"‏ ‏.‏\hadithno{3544}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from a man from the family of Sharid whose name was ‘Amr, that his father said:“There was a leper among the delegation of Thaqif. The Prophet (ﷺ) sent word to him: ‘Go back, for we have accepted your oath of allegiance.’”}}
\hadithdefcmd{ibnmajah}{3545}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سَحَرَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَهُودِيٌّ مِنْ يَهُودِ بَنِي زُرَيْقٍ يُقَالُ لَهُ لَبِيدُ بْنُ الأَعْصَمِ حَتَّى كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُخَيَّلُ إِلَيْهِ أَنَّهُ يَفْعَلُ الشَّىْءَ وَلاَ يَفْعَلُهُ ‏.‏ قَالَتْ حَتَّى إِذَا كَانَ ذَاتَ يَوْمٍ أَوْ كَانَ ذَاتَ لَيْلَةٍ دَعَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ دَعَا ثُمَّ دَعَا ثُمَّ قَالَ ‏"‏ يَا عَائِشَةُ أَشَعَرْتِ أَنَّ اللَّهَ قَدْ أَفْتَانِي فِيمَا اسْتَفْتَيْتُهُ فِيهِ جَاءَنِي رَجُلاَنِ فَجَلَسَ أَحَدُهُمَا عِنْدَ رَأْسِي وَالآخَرُ عِنْدَ رِجْلِي فَقَالَ الَّذِي عِنْدَ رَأْسِي لِلَّذِي عِنْدَ رِجْلِي أَوِ الَّذِي عِنْدَ رِجْلِي لِلَّذِي عِنْدَ رَأْسِي مَا وَجَعُ الرَّجُلِ قَالَ مَطْبُوبٌ ‏.‏ قَالَ مَنْ طَبَّهُ قَالَ لَبِيدُ بْنُ الأَعْصَمِ ‏.‏ قَالَ فِي أَىِّ شَىْءٍ قَالَ فِي مُشْطٍ وَمُشَاطَةٍ وَجُفِّ طَلْعَةِ ذَكَرٍ ‏.‏ قَالَ وَأَيْنَ هُوَ قَالَ فِي بِئْرِ ذِي أَرْوَانَ ‏"‏ ‏.‏ قَالَتْ فَأَتَاهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ فِي أُنَاسٍ مِنْ أَصْحَابِهِ ثُمَّ جَاءَ فَقَالَ ‏"‏ وَاللَّهِ يَا عَائِشَةُ لَكَأَنَّ مَاءَهَا نُقَاعَةُ الْحِنَّاءِ وَلَكَأَنَّ نَخْلَهَا رُءُوسُ الشَّيَاطِينِ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ أَحْرَقْتَهُ قَالَ ‏"‏ لاَ أَمَّا أَنَا فَقَدْ عَافَانِيَ اللَّهُ وَكَرِهْتُ أَنْ أُثِيرَ عَلَى النَّاسِ مِنْهُ شَرًّا ‏"‏ ‏.‏ فَأَمَرَ بِهَا فَدُفِنَتْ ‏.‏\hadithno{3545}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Aishah said:“A Jew from among the Jews of Bani Zuraiq, whose name was Labid bin A’sam, cast a spell on the Prophet (ﷺ), and the Prophet (ﷺ) began to imagine that he had done something when he had not. One day, or one night, the Messenger of Allah (ﷺ) supplicated, and then supplicated again. Then he said: ‘O ‘Aishah, do you know that Allah has instructed me concerning the matter I asked Him about? Two men came to me, and one of them sat at my head and the other at my feet. The one at my head said to the one at my feet, or the one at my feet said to the one at my head "what is ailing this man ?" He said: “He has been affected by a spell.” He said: “Who cast the spell on him?” He said: “Labid bin A’sam.” He said: “With what?” He said: “With a comb and the hairs stuck to it, and the spathe of a male date palm.” He said: “Where is that?” He said: “In the well of Dhu Arwan.” She said: “So the Prophet (ﷺ) went to it, with a group of his Companions, then he came and said: ‘By Allah. O ‘Aishah. It was as if its water was infused with henna and its date palms were like the heads of devils.’” She said: “I said: ‘O Messenger of Allah, why don’t you burn them?’ He said: ‘As for me, Allah has healed me, and I do not like to let evil spread among the people.’ Then he issued orders that the well be filled up with earth.”}}
\hadithdefcmd{ibnmajah}{3546}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا أَبُو بَكْرٍ الْعَنْسِيُّ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، وَمُحَمَّدِ بْنِ يَزِيدَ الْمِصْرِيَّيْنِ، قَالاَ حَدَّثَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَتْ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ لاَ يَزَالُ يُصِيبُكَ كُلَّ عَامٍ وَجَعٌ مِنَ الشَّاةِ الْمَسْمُومَةِ الَّتِي أَكَلْتَ ‏.‏ قَالَ ‏ "‏ مَا أَصَابَنِي شَىْءٌ مِنْهَا إِلاَّ وَهُوَ مَكْتُوبٌ عَلَىَّ وَآدَمُ فِي طِينَتِهِ ‏"‏ ‏.‏\hadithno{3546}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that Umm Salamah said:“O Messenger of Allah, every year you are still suffering pain because of the poisoned meat that you ate.” He said: “Nothing that happens to me, but it was decreed for me when Adam was still at the stage of being clay.’”}}
\hadithdefcmd{ibnmajah}{3547}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ مَالِكٍ، عَنْ خَوْلَةَ بِنْتِ حَكِيمٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَوْ أَنَّ أَحَدَكُمْ إِذَا نَزَلَ مَنْزِلاً قَالَ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ شَرِّ مَا خَلَقَ - لَمْ يَضُرَّهُ فِي ذَلِكَ الْمَنْزِلِ شَىْءٌ حَتَّى يَرْتَحِلَ مِنْهُ ‏"‏ ‏.‏\hadithno{3547}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Khawlah bint Hakim that the Prophet (ﷺ) said:“If anyone of you, when he stops to camp (while on a journey), says A’udhu bi kalimatil-lahit-tammati min sharri ma khalaq (I seek refuge in the Perfect Words of Allah from the evil of that which He has created), then nothing will harm him in that place until he moves on.”}}
\hadithdefcmd{ibnmajah}{3548}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنِي عُيَيْنَةُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي أَبِي، عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، قَالَ لَمَّا اسْتَعْمَلَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى الطَّائِفِ جَعَلَ يَعْرِضُ لِي شَىْءٌ فِي صَلاَتِي حَتَّى مَا أَدْرِي مَا أُصَلِّي فَلَمَّا رَأَيْتُ ذَلِكَ رَحَلْتُ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ ابْنُ أَبِي الْعَاصِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ مَا جَاءَ بِكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ عَرَضَ لِي شَىْءٌ فِي صَلاَتِي حَتَّى مَا أَدْرِي مَا أُصَلِّي ‏.‏ قَالَ ‏"‏ ذَاكَ الشَّيْطَانُ ادْنُهْ ‏"‏ ‏.‏ فَدَنَوْتُ مِنْهُ فَجَلَسْتُ عَلَى صُدُورِ قَدَمَىَّ ‏.‏ قَالَ فَضَرَبَ صَدْرِي بِيَدِهِ وَتَفَلَ فِي فَمِي وَقَالَ ‏"‏ اخْرُجْ عَدُوَّ اللَّهِ ‏"‏ ‏.‏ فَفَعَلَ ذَلِكَ ثَلاَثَ مَرَّاتٍ ثُمَّ قَالَ ‏"‏ الْحَقْ بِعَمَلِكَ ‏"‏ ‏.‏ قَالَ فَقَالَ عُثْمَانُ فَلَعَمْرِي مَا أَحْسِبُهُ خَالَطَنِي بَعْدُ ‏.‏\hadithno{3548}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Uthman bin Abul-‘As said:“When the Messenger of Allah (ﷺ) appointed me as governor of Ta’if, I began to get confused during my prayer, until I no longer knew what I was doing. When I noticed that, I travelled to the Messenger of Allah (ﷺ), and he said: ‘The son of Abul-‘As?’ I said: ‘Yes, O Messenger of Allah.’ He said: ‘What brings you here?’ He said: ‘O Messenger of Allah, I get confused during my prayer, until I do not know what I am doing.’ He said: ‘That is Satan. Come here.’ So I came close to him, and sat upon the front part of my feet then he struck my chest with his hand and put some spittle in my mouth and said: ‘Get out, O enemy of Allah!’ He did that three times, then he said: ‘Get on with your work.’” ‘Uthman said: “Indeed, I never felt confused (during my prayer) after that.”}}
\hadithdefcmd{ibnmajah}{3549}{حَدَّثَنَا هَارُونُ بْنُ حَيَّانَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَنْبَأَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، حَدَّثَنَا أَبُو جَنَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أَبِيهِ أَبِي لَيْلَى، قَالَ كُنْتُ جَالِسًا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ إِذْ جَاءَهُ أَعْرَابِيٌّ فَقَالَ إِنَّ لِي أَخًا وَجِعًا ‏.‏ قَالَ ‏"‏ مَا وَجَعُ أَخِيكَ ‏"‏ ‏.‏ قَالَ بِهِ لَمَمٌ ‏.‏ قَالَ ‏"‏ اذْهَبْ فَأْتِنِي بِهِ ‏"‏ ‏.‏ قَالَ فَذَهَبَ فَجَاءَ بِهِ فَأَجْلَسَهُ بَيْنَ يَدَيْهِ فَسَمِعْتُهُ عَوَّذَهُ بِفَاتِحَةِ الْكِتَابِ وَأَرْبَعِ آيَاتٍ مِنْ أَوَّلِ الْبَقَرَةِ وَآيَتَيْنِ مِنْ وَسَطِهَا وَإِلَهُكُمْ إِلَهٌ وَاحِدٌ وَآيَةِ الْكُرْسِيِّ وَثَلاَثِ آيَاتٍ مِنْ خَاتِمَتِهَا وَآيَةٍ مِنْ آلِ عِمْرَانَ - أَحْسِبُهُ قَالَ ‏\{شَهِدَ اللَّهُ أَنَّهُ لاَ إِلَهَ إِلاَّ هُوَ\}‏ - وَآيَةٍ مِنَ الأَعْرَافِ ‏\{إِنَّ رَبَّكُمُ اللَّهُ الَّذِي خَلَقَ\}‏ الآيَةَ وَآيَةٍ مِنَ الْمُؤْمِنِينَ ‏\{وَمَنْ يَدْعُ مَعَ اللَّهِ إِلهًا آخَرَ لاَ بُرْهَانَ لَهُ بِهِ \}‏ وَآيَةٍ مِنَ الْجِنِّ ‏\{وَأَنَّهُ تَعَالَى جَدُّ رِبِّنَا مَا اتَّخَذَ صَاحِبَةً وَلاَ وَلَدًا\}‏ وَعَشْرِ آيَاتٍ مِنْ أَوَّلِ الصَّافَّاتِ وَثَلاَثِ آيَاتٍ مِنْ آخِرِ الْحَشْرِ وَ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ \}‏ وَالْمُعَوِّذَتَيْنِ ‏.‏ فَقَامَ الأَعْرَابِيُّ قَدْ بَرَأَ لَيْسَ بِهِ بَأْسٌ ‏.‏\hadithno{3549}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Abi Laila that his father Abu Laila said:“I was sitting with the Prophet (ﷺ) when a Bedouin came to him and said: ‘I have a brother who is sick.’ He said: ‘What is the matter with your brother?’ He said: ‘He suffers from a slight mental derangement.’ He said: ‘Go and bring him.’” He said: “(So he went) and he brought him. He made him sit down in front of him and I heard him seeking refuge for him with Fatihatil-Kitab; four Verses from the beginning of Al-Baqarah, two Verses from its middle: ‘And your Ilah (God) is One Ilah (God – Allah),’ [2:163] and Ayat Al-Kursi; and three Verses from its end; a Verse from Al ‘Imran, I think it was: ‘Allah bears witness that La ilaha illa Huwa (none has the right to be worshipped but He),’ [3:18] a Verse from Al-A’raf: ‘Indeed, your Lord is Allah,’ [7:54] a Verse from Al-Mu’minun: ‘And whoever invokes (or worships), besides Allah, any other ilah (god), of whom he has no proof,’[23:117] a Verse from Al-Jinn: ‘And He, exalted is the Majesty of our Lord,’ [72:3] ten Verses from the beginning of As-Saffat; three Verses from the end of Al-Hashr; (then) ‘Say: He is Allah, (the) One,’ [112:1] and Al-Mu’awwidhatain. Then the Bedouin stood up, healed, and there was nothing wrong with him.”}}
